@@ -4,10 +4,13 @@
 Creating an Explicit Structured Grid
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-Create an explicit structured grid from NumPy arrays.
+Create an explicit structured grid from NumPy arrays using
+:class:`pyvista.ExplicitStructuredGrid`.
 
 """
 
+from __future__ import annotations
+
 import numpy as np
 
 import pyvista as pv
