@@ -4,11 +4,15 @@
 Geometric Objects
 ~~~~~~~~~~~~~~~~~
 
-The "Hello, world!" of VTK
+The "Hello, world!" of VTK.
+Uses objects from :ref:`geometry_api`.
 """
+
+from __future__ import annotations
+
 import pyvista as pv
 
-###############################################################################
+# %%
 # This runs through several of the available geometric objects available in
 # VTK which PyVista provides simple convenience methods for generating.
 #
@@ -24,7 +28,7 @@ cone = pv.Cone()
 poly = pv.Polygon()
 disc = pv.Disc()
 
-###############################################################################
+# %%
 # Now let's plot them all in one window
 
 p = pv.Plotter(shape=(3, 3))
