@@ -5,11 +5,15 @@ Plot Truss-like FEA Solution with Cylinders
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 Plot connections between points in 3D as cylinders, colored by scalars.
+Lines are created in a :class:`pyvista.PolyData` and then rendered as
+cylinders.
 
 
 """
 
 # sphinx_gallery_start_ignore
+from __future__ import annotations
+
 PYVISTA_GALLERY_FORCE_STATIC_IN_DOCUMENT = True
 # sphinx_gallery_end_ignore
 
@@ -17,7 +21,7 @@ import numpy as np
 
 import pyvista
 
-###############################################################################
+# %%
 # Define the points and elements of the truss.  Call them ``nodes``
 # here as it comes from finite element analysis.
 
@@ -43,7 +47,7 @@ edges = np.array(
         [2, 5],
         [5, 6],
         [2, 6],
-    ]
+    ],
 )
 
 # We must "pad" the edges to indicate to vtk how many points per edge
@@ -52,7 +56,7 @@ padding[:] = 2
 edges_w_padding = np.vstack((padding, edges.T)).T
 edges_w_padding
 
-###############################################################################
+# %%
 # Plot the truss while rendering the lines as tubes.
 
 mesh = pyvista.PolyData(nodes, edges_w_padding)
