@@ -9,14 +9,17 @@ https://en.wikipedia.org/wiki/VRML
 
 """
 
+from __future__ import annotations
+
 import pyvista
 from pyvista import examples
 
 sextant_file = examples.vrml.download_sextant()
 
 
-###############################################################################
+# %%
 # Set up the plotter and import VRML file.
+# Use :func:`pyvista.Plotter.import_vrml` to import file.
 
 pl = pyvista.Plotter()
 pl.import_vrml(sextant_file)
