@@ -6,9 +6,12 @@ Extract the cells in a mesh that exist inside or outside a closed surface of
 another mesh
 
 """
-###############################################################################
+
+# %%
 
 # sphinx_gallery_thumbnail_number = 2
+from __future__ import annotations
+
 import pyvista as pv
 from pyvista import examples
 
@@ -26,19 +29,19 @@ p.add_mesh(rot, color="mintcream", opacity=0.35, **dargs)
 p.camera_position = cpos
 p.show()
 
-###############################################################################
+# %%
 # Mark points inside with 1 and outside with a 0
 select = mesh.select_enclosed_points(rot)
 
 select
-###############################################################################
+# %%
 # Extract two meshes, one completely inside and one completely outside the
 # enclosing surface.
 
 inside = select.threshold(0.5)
 outside = select.threshold(0.5, invert=True)
 
-###############################################################################
+# %%
 # display the results
 
 p = pv.Plotter()
