@@ -9,9 +9,11 @@ we create a voxelized mesh similar to a Minecraft "cave".
 
 """
 
+from __future__ import annotations
+
 import pyvista as pv
 
-###############################################################################
+# %%
 # Generate Perlin Noise over a 3D StructuredGrid
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 # Feel free to change the values of ``freq`` to change the shape of
@@ -28,7 +30,7 @@ grid = pv.sample_function(noise, [0, 3.0, -0, 1.0, 0, 1.0], dim=(120, 40, 40))
 out = grid.threshold(0.02)
 out
 
-###############################################################################
+# %%
 # color limits without blue
 mn, mx = [out['scalars'].min(), out['scalars'].max()]
 clim = (mn, mx * 1.8)
