@@ -7,6 +7,9 @@ Background Image
 Add a background image with :func:`pyvista.Plotter.add_background_image`.
 
 """
+
+from __future__ import annotations
+
 import pyvista as pv
 from pyvista import examples
 
@@ -15,7 +18,7 @@ from pyvista import examples
 PYVISTA_GALLERY_FORCE_STATIC_IN_DOCUMENT = True
 # sphinx_gallery_end_ignore
 
-###############################################################################
+# %%
 # Plot an airplane with the map of the earth in the background
 earth_alt = examples.download_topo_global()
 
@@ -24,7 +27,7 @@ actor = pl.add_mesh(examples.load_airplane(), smooth_shading=True)
 pl.add_background_image(examples.mapfile)
 pl.show()
 
-###############################################################################
+# %%
 # Plot several earth related plots
 
 pl = pv.Plotter(shape=(2, 2))
