@@ -10,6 +10,8 @@ to highlight part of your plot.
 
 """
 
+from __future__ import annotations
+
 import pyvista as pv
 
 # sphinx_gallery_start_ignore
@@ -18,7 +20,7 @@ import pyvista as pv
 PYVISTA_GALLERY_FORCE_STATIC_IN_DOCUMENT = True
 # sphinx_gallery_end_ignore
 
-###############################################################################
+# %%
 # Create several spheres
 # ~~~~~~~~~~~~~~~~~~~~~~
 
@@ -29,7 +31,7 @@ grid = pv.ImageData(dimensions=(4, 4, 4), spacing=(1, 1, 1))
 spheres = grid.glyph(geom=pv.Sphere(), scale=False, orient=False)
 
 
-###############################################################################
+# %%
 # Blur the plot
 # ~~~~~~~~~~~~~
 # Add a few blur passes to blur the plot
@@ -44,7 +46,7 @@ pl.enable_anti_aliasing('ssaa')
 pl.show()
 
 
-###############################################################################
+# %%
 # Note how this is different than selectively blurring part of the mesh behind
 # the focal plane
 
