@@ -5,6 +5,9 @@ Render a depth image
 Plot a depth image as viewed from a camera overlooking the "hills"
 example mesh.
 """
+
+from __future__ import annotations
+
 import matplotlib.pyplot as plt
 
 # sphinx_gallery_thumbnail_number = 2
@@ -19,12 +22,12 @@ p = pv.Plotter()
 p.add_mesh(mesh, color=True)
 p.show()
 
-###############################################################################
+# %%
 # Record depth image without and with a custom fill value
 zval = p.get_image_depth()
 zval_filled_by_42s = p.get_image_depth(fill_value=42.0)
 
-###############################################################################
+# %%
 # Visualize depth images
 plt.figure()
 plt.imshow(zval)
@@ -34,7 +37,7 @@ plt.xlabel('X Pixel')
 plt.ylabel('Y Pixel')
 plt.show()
 
-###############################################################################
+# %%
 plt.figure()
 plt.imshow(zval_filled_by_42s)
 plt.title('Depth image (custom fill_value)')
