@@ -7,6 +7,8 @@ Interpolate the scalars of a dataset over a circular arc.
 """
 
 # sphinx_gallery_thumbnail_number = 2
+from __future__ import annotations
+
 import pyvista as pv
 from pyvista import examples
 
@@ -15,7 +17,7 @@ from pyvista import examples
 PYVISTA_GALLERY_FORCE_STATIC_IN_DOCUMENT = True
 # sphinx_gallery_end_ignore
 
-###############################################################################
+# %%
 # Volumetric Mesh
 # +++++++++++++++
 #
@@ -41,6 +43,6 @@ b = arc.points[-1]
 p.add_point_labels([a, b], ["A", "B"], font_size=48, point_color="red", text_color="red")
 p.show()
 
-###############################################################################
+# %%
 # Run the filter and produce a line plot.
 mesh.plot_over_circular_arc_normal(center, 100, normal, polar, angle, 'height')
