@@ -2,6 +2,9 @@
 Saving Screenshots
 ~~~~~~~~~~~~~~~~~~
 """
+
+from __future__ import annotations
+
 import matplotlib.pyplot as plt
 
 # sphinx_gallery_thumbnail_number = 2
@@ -13,7 +16,7 @@ filename = examples.planefile
 mesh = pv.read(filename)
 
 
-###############################################################################
+# %%
 # You can also take a screenshot without creating an interactive plot window
 # using the :class:`pyvista.Plotter`:
 
@@ -21,7 +24,7 @@ plotter = pv.Plotter(off_screen=True)
 plotter.add_mesh(mesh, color="orange")
 plotter.show(screenshot='airplane.png')
 
-###############################################################################
+# %%
 # The ``img`` array can be used to plot the screenshot in ``matplotlib``:
 
 plt.imshow(plotter.image)
