@@ -10,6 +10,8 @@ This allows you to pick points on the surface of a mesh.
 
 """
 
+from __future__ import annotations
+
 import pyvista as pv
 
 # sphinx_gallery_start_ignore
@@ -17,7 +19,7 @@ import pyvista as pv
 PYVISTA_GALLERY_FORCE_STATIC_IN_DOCUMENT = True
 # sphinx_gallery_end_ignore
 
-###############################################################################
+# %%
 # Create a mesh and enable picking using the default settings.
 
 cube = pv.Cube()
@@ -28,7 +30,7 @@ pl.enable_surface_point_picking()
 pl.show()
 
 
-###############################################################################
+# %%
 # Enable a callback that creates a cube at the right-clicked point and add a
 # label at the point as well it.
 
