@@ -8,6 +8,8 @@ We can plot individual components of multi-component arrays with the
 ``component`` argument  of the ``add_mesh`` method.
 """
 
+from __future__ import annotations
+
 import pyvista as pv
 from pyvista import examples
 
@@ -17,12 +19,12 @@ PYVISTA_GALLERY_FORCE_STATIC_IN_DOCUMENT = True
 # sphinx_gallery_end_ignore
 
 
-###############################################################################
+# %%
 # Download an example notched beam stress
 mesh = examples.download_notch_displacement()
 
 
-###############################################################################
+# %%
 # The default behavior with no component specified is to use the
 # vector magnitude. We can access each component by specifying the
 # component argument.
