@@ -21,6 +21,8 @@ scene with a box widget that controls its extent, the
 
 # sphinx_gallery_start_ignore
 # widgets do not work in interactive examples
+from __future__ import annotations
+
 PYVISTA_GALLERY_FORCE_STATIC_IN_DOCUMENT = True
 # sphinx_gallery_end_ignore
 
@@ -30,13 +32,13 @@ from pyvista import examples
 
 mesh = examples.download_nefertiti()
 
-###############################################################################
+# %%
 
 p = pv.Plotter()
 p.add_mesh_clip_box(mesh, color='white')
 p.show(cpos=[-1, -1, 0.2])
 
 
-###############################################################################
+# %%
 # After interacting with the scene, the clipped mesh is available as:
 p.box_clipped_meshes
