@@ -1,13 +1,15 @@
+from __future__ import annotations
+
 from trame.app import get_server
-from trame.ui.vuetify import SinglePageLayout
-from trame.widgets import vuetify
+from trame.ui.vuetify3 import SinglePageLayout
+from trame.widgets import vuetify3
 
 import pyvista as pv
 from pyvista.trame.ui import plotter_ui
 
 pv.OFF_SCREEN = True
 
-server = get_server()
+server = get_server(client_type="vue3")
 state, ctrl = server.state, server.controller
 
 state.trame__title = "PyVista Many Actors"
@@ -30,7 +32,7 @@ with SinglePageLayout(server) as layout:
     layout.title.set_text(state.trame__title)
 
     with layout.toolbar:
-        vuetify.VSpacer()
+        vuetify3.VSpacer()
 
     with layout.content:
         # Use PyVista UI template for Plotters
