@@ -1,17 +1,30 @@
 """Contains the pyvista.Cell class."""
+
 from __future__ import annotations
 
-from typing import List, Optional, Tuple, Union, cast
+from typing import TYPE_CHECKING
+from typing import Tuple
+from typing import cast
+import warnings
 
 import numpy as np
 
 import pyvista
 
 from . import _vtk_core as _vtk
-from ._typing_core import IntMatrix, IntVector, NumpyIntArray
 from .celltype import CellType
 from .dataset import DataObject
-from .utilities.cells import ncells_from_cells, numpy_to_idarr
+from .errors import CellSizeError
+from .errors import PyVistaDeprecationWarning
+from .utilities.cells import numpy_to_idarr
+
+if TYPE_CHECKING:  # pragma: no cover
+    from typing import Sequence
+
+    from ._typing_core import CellsLike
+    from ._typing_core import MatrixLike
+    from ._typing_core import NumpyArray
+    from ._typing_core import VectorLike
 
 
 def _get_vtk_id_type():
@@ -24,7 +37,7 @@ def _get_vtk_id_type():
     return np.int32
 
 
-class Cell(_vtk.vtkGenericCell, DataObject):
+class Cell(DataObject, _vtk.vtkGenericCell):
     """Wrapping of vtkCell.
 
     This class provides the capability to access a given cell topology and can
@@ -108,7 +121,7 @@ class Cell(_vtk.vtkGenericCell, DataObject):
                 self.ShallowCopy(vtk_cell)
 
     @property
-    def type(self) -> CellType:  # numpydoc ignore=RT01
+    def type(self) -> CellType:
         """Get the cell type from the enum :class:`pyvista.CellType`.
 
         Returns
@@ -126,7 +139,7 @@ class Cell(_vtk.vtkGenericCell, DataObject):
         return CellType(self.GetCellType())
 
     @property
-    def is_linear(self) -> bool:  # numpydoc ignore=RT01
+    def is_linear(self) -> bool:
         """Return if the cell is linear.
 
         Returns
@@ -190,7 +203,7 @@ class Cell(_vtk.vtkGenericCell, DataObject):
           N Arrays:   0
 
         """
-        cells = [len(self.point_ids)] + list(range(len(self.point_ids)))
+        cells = [len(self.point_ids), *list(range(len(self.point_ids)))]
         if self.dimension == 0:
             return pyvista.PolyData(self.points.copy(), verts=cells)
         if self.dimension == 1:
@@ -235,7 +248,7 @@ class Cell(_vtk.vtkGenericCell, DataObject):
                 cell_ids.extend(self.point_ids.index(i) for i in face.point_ids)
             cell_ids.insert(0, len(cell_ids))
         else:
-            cell_ids = [len(self.point_ids)] + list(range(len(self.point_ids)))
+            cell_ids = [len(self.point_ids), *list(range(len(self.point_ids)))]
         return pyvista.UnstructuredGrid(
             cell_ids,
             [int(self.type)],
@@ -243,7 +256,7 @@ class Cell(_vtk.vtkGenericCell, DataObject):
         )
 
     @property
-    def dimension(self) -> int:  # numpydoc ignore=RT01
+    def dimension(self) -> int:
         """Return the cell dimension.
 
         This returns the dimensionality of the cell. For example, 1 for an edge,
@@ -264,7 +277,7 @@ class Cell(_vtk.vtkGenericCell, DataObject):
         return self.GetCellDimension()
 
     @property
-    def n_points(self) -> int:  # numpydoc ignore=RT01
+    def n_points(self) -> int:
         """Get the number of points composing the cell.
 
         Returns
@@ -282,7 +295,7 @@ class Cell(_vtk.vtkGenericCell, DataObject):
         return self.GetNumberOfPoints()
 
     @property
-    def n_faces(self) -> int:  # numpydoc ignore=RT01
+    def n_faces(self) -> int:
         """Get the number of faces composing the cell.
 
         Returns
@@ -300,7 +313,7 @@ class Cell(_vtk.vtkGenericCell, DataObject):
         return self.GetNumberOfFaces()
 
     @property
-    def n_edges(self) -> int:  # numpydoc ignore=RT01
+    def n_edges(self) -> int:
         """Get the number of edges composing the cell.
 
         Returns
@@ -318,12 +331,12 @@ class Cell(_vtk.vtkGenericCell, DataObject):
         return self.GetNumberOfEdges()
 
     @property
-    def point_ids(self) -> List[int]:  # numpydoc ignore=RT01
+    def point_ids(self) -> list[int]:
         """Get the point IDs composing the cell.
 
         Returns
         -------
-        List[int]
+        list[int]
             The point IDs composing the cell.
 
         Examples
@@ -337,7 +350,7 @@ class Cell(_vtk.vtkGenericCell, DataObject):
         return [point_ids.GetId(i) for i in range(point_ids.GetNumberOfIds())]
 
     @property
-    def points(self) -> np.ndarray:  # numpydoc ignore=RT01
+    def points(self) -> NumpyArray[float]:
         """Get the point coordinates of the cell.
 
         Returns
@@ -390,12 +403,12 @@ class Cell(_vtk.vtkGenericCell, DataObject):
         return Cell(self.GetEdge(index), deep=True)
 
     @property
-    def edges(self) -> List[Cell]:  # numpydoc ignore=RT01
+    def edges(self) -> list[Cell]:
         """Return a list of edges composing the cell.
 
         Returns
         -------
-        List[Cell]
+        list[Cell]
             A list of edges composing the cell.
 
         Examples
@@ -411,12 +424,12 @@ class Cell(_vtk.vtkGenericCell, DataObject):
         return [self.get_edge(i) for i in range(self.n_edges)]
 
     @property
-    def faces(self) -> List[Cell]:  # numpydoc ignore=RT01
+    def faces(self) -> list[Cell]:
         """Return a list of faces composing the cell.
 
         Returns
         -------
-        List[Cell]
+        list[Cell]
             A list of faces composing the cell.
 
         Examples
@@ -466,12 +479,12 @@ class Cell(_vtk.vtkGenericCell, DataObject):
         return Cell(cell, deep=True, cell_type=cell.GetCellType())
 
     @property
-    def bounds(self) -> Tuple[float, float, float, float, float, float]:  # numpydoc ignore=RT01
+    def bounds(self) -> tuple[float, float, float, float, float, float]:
         """Get the cell bounds in ``[xmin, xmax, ymin, ymax, zmin, zmax]``.
 
         Returns
         -------
-        Tuple[float, float, float, float, float, float]
+        tuple[float, float, float, float, float, float]
             The cell bounds in ``[xmin, xmax, ymin, ymax, zmin, zmax]``.
 
         Examples
@@ -485,14 +498,14 @@ class Cell(_vtk.vtkGenericCell, DataObject):
         return self.GetBounds()
 
     @property
-    def center(self) -> Tuple[float, float, float]:  # numpydoc ignore=RT01
+    def center(self) -> tuple[float, float, float]:
         """Get the center of the cell.
 
         Uses parametric coordinate center to determine x-y-z center.
 
         Returns
         -------
-        Tuple[float, float, float]
+        tuple[float, float, float]
             The center of the cell.
 
         Examples
@@ -582,6 +595,9 @@ class CellArray(_vtk.vtkCellArray):
     Provides convenience functions to simplify creating a CellArray from
     a numpy array or list.
 
+    .. deprecated:: 0.44.0
+       The parameters ``n_cells`` and ``deep`` are deprecated and no longer used.
+
     Parameters
     ----------
     cells : np.ndarray or list, optional
@@ -613,35 +629,27 @@ class CellArray(_vtk.vtkCellArray):
 
     def __init__(
         self,
-        cells: Optional[Union[IntMatrix, IntVector]] = None,
-        n_cells: Optional[int] = None,
-        deep: bool = False,
+        cells: CellsLike | None = None,
+        n_cells: int | None = None,
+        deep: bool | None = None,
     ):
         """Initialize a vtkCellArray."""
-        self.__offsets: Optional[_vtk.vtkIdTypeArray] = None
-        self.__connectivity: Optional[_vtk.vtkIdTypeArray] = None
+        super().__init__()
+        self.__offsets: _vtk.vtkIdTypeArray | None = None
+        self.__connectivity: _vtk.vtkIdTypeArray | None = None
         if cells is not None:
-            self._set_cells(np.asarray(cells), n_cells, deep)
+            self.cells = cells  # type: ignore[assignment]
 
-    def _set_cells(self, cells: NumpyIntArray, n_cells: Optional[int], deep: bool) -> None:
-        """Set a vtkCellArray."""
-        vtk_idarr, cells = numpy_to_idarr(cells, deep=deep, return_ind=True)  # type: ignore
-
-        # Get number of cells if None.  This is quite a performance
-        # bottleneck and we can consider adding a warning.  Good
-        # candidate for Cython or JIT compilation
-        if n_cells is None:
-            if cells.ndim == 1:
-                n_cells = ncells_from_cells(cells)
-            else:
-                n_cells = cells.shape[0]
-
-        self.SetCells(n_cells, vtk_idarr)
-        self.__offsets = self.__connectivity = None
-        return None
+        # deprecated 0.44.0, convert to error in 0.47.0, remove 0.48.0
+        for k, v in (('n_cells', n_cells), ('deep', deep)):
+            if v is not None:
+                warnings.warn(
+                    f"`CellArray parameter `{k}` is deprecated and no longer used.",
+                    PyVistaDeprecationWarning,
+                )
 
     @property
-    def cells(self) -> np.ndarray:  # numpydoc ignore=RT01
+    def cells(self) -> NumpyArray[int]:
         """Return a numpy array of the cells.
 
         Returns
@@ -649,10 +657,30 @@ class CellArray(_vtk.vtkCellArray):
         np.ndarray
             A numpy array of the cells.
         """
-        return _vtk.vtk_to_numpy(self.GetData()).ravel()
+        cells = _vtk.vtkIdTypeArray()
+        self.ExportLegacyFormat(cells)
+        return _vtk.vtk_to_numpy(cells)
+
+    @cells.setter
+    def cells(self, cells: CellsLike):  # numpydoc ignore=GL08
+        cells = np.asarray(cells)
+        vtk_idarr = numpy_to_idarr(cells, deep=False, return_ind=False)
+        self.ImportLegacyFormat(vtk_idarr)
+        imported_size = self.GetNumberOfConnectivityEntries()
+
+        # https://github.com/pyvista/pyvista/pull/5404
+        if imported_size != cells.size:
+            raise CellSizeError(
+                message=(
+                    f"Cell array size is invalid. Size ({cells.size}) does not"
+                    f" match expected size ({imported_size}). This is likely"
+                    " due to invalid connectivity array."
+                ),
+            )
+        self.__offsets = self.__connectivity = None
 
     @property
-    def n_cells(self) -> int:  # numpydoc ignore=RT01
+    def n_cells(self) -> int:
         """Return the number of cells.
 
         Returns
@@ -663,7 +691,7 @@ class CellArray(_vtk.vtkCellArray):
         return self.GetNumberOfCells()
 
     @property
-    def connectivity_array(self) -> NumpyIntArray:  # numpydoc ignore=RT01
+    def connectivity_array(self) -> NumpyArray[int]:
         """Return the array with the point ids that define the cells' connectivity.
 
         Returns
@@ -674,7 +702,7 @@ class CellArray(_vtk.vtkCellArray):
         return _get_connectivity_array(self)
 
     @property
-    def offset_array(self) -> NumpyIntArray:  # numpydoc ignore=RT01
+    def offset_array(self) -> NumpyArray[int]:
         """Return the array used to store cell offsets.
 
         Returns
@@ -684,7 +712,12 @@ class CellArray(_vtk.vtkCellArray):
         """
         return _get_offset_array(self)
 
-    def _set_data(self, offsets: IntMatrix, connectivity: IntMatrix, deep: bool = False) -> None:
+    def _set_data(
+        self,
+        offsets: MatrixLike[int],
+        connectivity: MatrixLike[int],
+        deep: bool = False,
+    ) -> None:
         """Set the offsets and connectivity arrays."""
         vtk_offsets = cast(_vtk.vtkIdTypeArray, numpy_to_idarr(offsets, deep=deep))
         vtk_connectivity = cast(_vtk.vtkIdTypeArray, numpy_to_idarr(connectivity, deep=deep))
@@ -694,12 +727,11 @@ class CellArray(_vtk.vtkCellArray):
         # garbage collected. Keep a reference to them for safety
         self.__offsets = vtk_offsets
         self.__connectivity = vtk_connectivity
-        return None
 
     @staticmethod
     def from_arrays(
-        offsets: IntMatrix,
-        connectivity: IntMatrix,
+        offsets: MatrixLike[int],
+        connectivity: MatrixLike[int],
         deep: bool = False,
     ) -> CellArray:
         """Construct a CellArray from offsets and connectivity arrays.
@@ -726,7 +758,7 @@ class CellArray(_vtk.vtkCellArray):
         return cellarr
 
     @property
-    def regular_cells(self) -> NumpyIntArray:  # numpydoc ignore=RT01
+    def regular_cells(self) -> NumpyArray[int]:
         """Return an array of shape (n_cells, cell_size) of point indices when all faces have the same size.
 
         Returns
@@ -743,7 +775,7 @@ class CellArray(_vtk.vtkCellArray):
         return _get_regular_cells(self)
 
     @classmethod
-    def from_regular_cells(cls, cells: IntMatrix, deep: bool = False) -> pyvista.CellArray:
+    def from_regular_cells(cls, cells: MatrixLike[int], deep: bool = False) -> pyvista.CellArray:
         """Construct a ``CellArray`` from a (n_cells, cell_size) array of cell indices.
 
         Parameters
@@ -766,6 +798,25 @@ class CellArray(_vtk.vtkCellArray):
         cellarr._set_data(offsets, cells, deep=deep)
         return cellarr
 
+    @classmethod
+    def from_irregular_cells(cls, cells: Sequence[VectorLike[int]]) -> pyvista.CellArray:
+        """Construct a ``CellArray`` from a (n_cells, cell_size) array of cell indices.
+
+        Parameters
+        ----------
+        cells : numpy.ndarray or list[list[int]]
+            Cell array of shape (n_cells, cell_size) where all cells have the same size `cell_size`.
+
+        Returns
+        -------
+        pyvista.CellArray
+            Constructed ``CellArray``.
+        """
+        offsets = np.cumsum([len(c) for c in cells])
+        offsets = np.concatenate([[0], offsets], dtype=pyvista.ID_TYPE)
+        connectivity = np.concatenate(cells, dtype=pyvista.ID_TYPE)
+        return cls.from_arrays(offsets, connectivity)
+
 
 # The following methods would be much nicer bound to CellArray,
 # but then they wouldn't be available on bare vtkCellArrays. In the future,
@@ -773,17 +824,17 @@ class CellArray(_vtk.vtkCellArray):
 # returned as CellArrays
 
 
-def _get_connectivity_array(cellarr: _vtk.vtkCellArray) -> NumpyIntArray:
+def _get_connectivity_array(cellarr: _vtk.vtkCellArray) -> NumpyArray[int]:
     """Return the array with the point ids that define the cells' connectivity."""
     return _vtk.vtk_to_numpy(cellarr.GetConnectivityArray())
 
 
-def _get_offset_array(cellarr: _vtk.vtkCellArray) -> np.ndarray:
+def _get_offset_array(cellarr: _vtk.vtkCellArray) -> NumpyArray[int]:
     """Return the array used to store cell offsets."""
     return _vtk.vtk_to_numpy(cellarr.GetOffsetsArray())
 
 
-def _get_regular_cells(cellarr: _vtk.vtkCellArray) -> NumpyIntArray:
+def _get_regular_cells(cellarr: _vtk.vtkCellArray) -> NumpyArray[int]:
     """Return an array of shape (n_cells, cell_size) of point indices when all faces have the same size."""
     cells = _get_connectivity_array(cellarr)
     if len(cells) == 0:
@@ -792,3 +843,13 @@ def _get_regular_cells(cellarr: _vtk.vtkCellArray) -> NumpyIntArray:
     offsets = _get_offset_array(cellarr)
     cell_size = offsets[1] - offsets[0]
     return cells.reshape(-1, cell_size)
+
+
+def _get_irregular_cells(cellarr: _vtk.vtkCellArray) -> tuple[NumpyArray[int], ...]:
+    """Return a tuple of length n_cells of each cell's point indices."""
+    cells = _get_connectivity_array(cellarr)
+    if len(cells) == 0:
+        return ()
+
+    offsets = _get_offset_array(cellarr)
+    return tuple(np.split(cells, offsets[1:-1]))
