@@ -3,29 +3,49 @@
 These classes hold many VTK datasets in one object that can be passed
 to VTK algorithms and PyVista filtering/plotting routines.
 """
-import collections.abc
+
+from __future__ import annotations
+
+from collections.abc import MutableSequence
 from itertools import zip_longest
 import pathlib
-from typing import Any, Iterable, List, Optional, Set, Tuple, Union, cast, overload
+from typing import TYPE_CHECKING
+from typing import Any
+from typing import List
+from typing import Union
+from typing import cast
+from typing import overload
 
 import numpy as np
 
 import pyvista
+from pyvista.core import _validation
 
 from . import _vtk_core as _vtk
-from ._typing_core import BoundsLike
-from .dataset import DataObject, DataSet
+
+if TYPE_CHECKING:  # pragma: no cover
+    from ._typing_core import BoundsLike
+    from ._typing_core import NumpyArray
+from .dataset import DataObject
+from .dataset import DataSet
 from .filters import CompositeFilters
 from .pyvista_ndarray import pyvista_ndarray
 from .utilities.arrays import FieldAssociation
 from .utilities.geometric_objects import Box
-from .utilities.helpers import is_pyvista_dataset, wrap
+from .utilities.helpers import is_pyvista_dataset
+from .utilities.helpers import wrap
+
+if TYPE_CHECKING:  # pragma: no cover
+    from collections.abc import Iterable
 
 _TypeMultiBlockLeaf = Union['MultiBlock', DataSet]
 
 
 class MultiBlock(
-    _vtk.vtkMultiBlockDataSet, CompositeFilters, DataObject, collections.abc.MutableSequence
+    CompositeFilters,
+    DataObject,
+    MutableSequence,  # type: ignore[type-arg]
+    _vtk.vtkMultiBlockDataSet,
 ):
     """A composite class to hold many data sets which can be iterated over.
 
@@ -134,7 +154,7 @@ class MultiBlock(
 
         elif len(args) > 1:
             raise ValueError(
-                'Invalid number of arguments:\n``pyvista.MultiBlock``' 'supports 0 or 1 arguments.'
+                'Invalid number of arguments:\n``pyvista.MultiBlock``supports 0 or 1 arguments.',
             )
 
         # Upon creation make sure all nested structures are wrapped
@@ -152,7 +172,7 @@ class MultiBlock(
                 self.SetBlock(i, wrap(block))
 
     @property
-    def bounds(self) -> BoundsLike:  # numpydoc ignore=RT01
+    def bounds(self) -> BoundsLike:
         """Find min/max for bounds across blocks.
 
         Returns
@@ -177,27 +197,25 @@ class MultiBlock(
         """
         # apply reduction of min and max over each block
         # (typing.cast necessary to make mypy happy with ufunc.reduce() later)
-        all_bounds = [cast(list, block.bounds) for block in self if block]
+        all_bounds = [cast(List[float], block.bounds) for block in self if block]
         # edge case where block has no bounds
         if not all_bounds:  # pragma: no cover
             minima = np.array([0.0, 0.0, 0.0])
             maxima = np.array([0.0, 0.0, 0.0])
         else:
-            minima = np.minimum.reduce(all_bounds)[::2]
-            maxima = np.maximum.reduce(all_bounds)[1::2]
+            minima = np.minimum.reduce(all_bounds)[::2].tolist()
+            maxima = np.maximum.reduce(all_bounds)[1::2].tolist()
 
         # interleave minima and maxima for bounds
-        the_bounds = np.stack([minima, maxima]).ravel('F')
-
-        return cast(BoundsLike, tuple(the_bounds))
+        return (minima[0], maxima[0], minima[1], maxima[1], minima[2], maxima[2])
 
     @property
-    def center(self) -> Any:  # numpydoc ignore=RT01
+    def center(self) -> NumpyArray[float]:
         """Return the center of the bounding box.
 
         Returns
         -------
-        Any
+        np.ndarray
             Center of the bounding box.
 
         Examples
@@ -214,10 +232,10 @@ class MultiBlock(
 
         """
         # (typing.cast necessary to make mypy happy with np.reshape())
-        return np.reshape(cast(list, self.bounds), (3, 2)).mean(axis=1)
+        return np.reshape(cast(List[float], self.bounds), (3, 2)).mean(axis=1)
 
     @property
-    def length(self) -> float:  # numpydoc ignore=RT01
+    def length(self) -> float:
         """Return the length of the diagonal of the bounding box.
 
         Returns
@@ -241,7 +259,7 @@ class MultiBlock(
         return Box(self.bounds).length
 
     @property
-    def n_blocks(self) -> int:  # numpydoc ignore=RT01
+    def n_blocks(self) -> int:
         """Return the total number of blocks set.
 
         Returns
@@ -278,7 +296,7 @@ class MultiBlock(
         self.Modified()
 
     @property
-    def volume(self) -> float:  # numpydoc ignore=RT01
+    def volume(self) -> float:
         """Return the total volume of all meshes in this dataset.
 
         Returns
@@ -301,7 +319,7 @@ class MultiBlock(
         """
         return sum(block.volume for block in self if block)
 
-    def get_data_range(self, name: str, allow_missing: bool = False) -> Tuple[float, float]:  # type: ignore
+    def get_data_range(self, name: str, allow_missing: bool = False) -> tuple[float, float]:  # type: ignore[explicit-override, override]
         """Get the min/max of an array given its name across all blocks.
 
         Parameters
@@ -326,11 +344,11 @@ class MultiBlock(
             # get the scalars if available - recursive
             try:
                 tmi, tma = data.get_data_range(name)
-            except KeyError as err:
+            except KeyError:
                 if allow_missing:
                     continue
                 else:
-                    raise err
+                    raise
             if not np.isnan(tmi) and tmi < mini:
                 mini = tmi
             if not np.isnan(tma) and tma > maxi:
@@ -369,12 +387,13 @@ class MultiBlock(
 
     @overload
     def __getitem__(
-        self, index: Union[int, str]
-    ) -> Optional[_TypeMultiBlockLeaf]:  # noqa: D105  # numpydoc ignore=GL08
+        self,
+        index: int | str,
+    ) -> _TypeMultiBlockLeaf | None:  # noqa: D105  # numpydoc ignore=GL08
         ...  # pragma: no cover
 
     @overload
-    def __getitem__(self, index: slice) -> 'MultiBlock':  # noqa: D105
+    def __getitem__(self, index: slice) -> MultiBlock:  # noqa: D105
         ...  # pragma: no cover
 
     def __getitem__(self, index):
@@ -398,7 +417,7 @@ class MultiBlock(
 
         return wrap(self.GetBlock(index))
 
-    def append(self, dataset: Optional[_TypeMultiBlockLeaf], name: Optional[str] = None):
+    def append(self, dataset: _TypeMultiBlockLeaf | None, name: str | None = None):
         """Add a data set to the next block index.
 
         Parameters
@@ -481,8 +500,10 @@ class MultiBlock(
                 self.append(v)
 
     def get(
-        self, index: str, default: Optional[_TypeMultiBlockLeaf] = None
-    ) -> Optional[_TypeMultiBlockLeaf]:
+        self,
+        index: str,
+        default: _TypeMultiBlockLeaf | None = None,
+    ) -> _TypeMultiBlockLeaf | None:
         """Get a block by its name.
 
         If the name is non-unique then returns the first occurrence.
@@ -517,7 +538,7 @@ class MultiBlock(
         except KeyError:
             return default
 
-    def set_block_name(self, index: int, name: Optional[str]):
+    def set_block_name(self, index: int, name: str | None):
         """Set a block's string name at the specified index.
 
         Parameters
@@ -549,7 +570,7 @@ class MultiBlock(
         self.GetMetaData(index).Set(_vtk.vtkCompositeDataSet.NAME(), name)
         self.Modified()
 
-    def get_block_name(self, index: int) -> Optional[str]:
+    def get_block_name(self, index: int) -> str | None:
         """Return the string name of the block at the given index.
 
         Parameters
@@ -580,7 +601,7 @@ class MultiBlock(
             return meta.Get(_vtk.vtkCompositeDataSet.NAME())
         return None
 
-    def keys(self) -> List[Optional[str]]:
+    def keys(self) -> list[str | None]:
         """Get all the block names in the dataset.
 
         Returns
@@ -602,10 +623,10 @@ class MultiBlock(
         """
         return [self.get_block_name(i) for i in range(self.n_blocks)]
 
-    def _ipython_key_completions_(self) -> List[Optional[str]]:
+    def _ipython_key_completions_(self) -> list[str | None]:
         return self.keys()
 
-    def replace(self, index: int, dataset: Optional[_TypeMultiBlockLeaf]) -> None:
+    def replace(self, index: int, dataset: _TypeMultiBlockLeaf | None) -> None:
         """Replace dataset at index while preserving key name.
 
         Parameters
@@ -637,19 +658,23 @@ class MultiBlock(
 
     @overload
     def __setitem__(
-        self, index: Union[int, str], data: Optional[_TypeMultiBlockLeaf]
+        self,
+        index: int | str,
+        data: _TypeMultiBlockLeaf | None,
     ):  # noqa: D105  # numpydoc ignore=GL08
         ...  # pragma: no cover
 
     @overload
     def __setitem__(
-        self, index: slice, data: Iterable[Optional[_TypeMultiBlockLeaf]]
+        self,
+        index: slice,
+        data: Iterable[_TypeMultiBlockLeaf | None],
     ):  # noqa: D105  # numpydoc ignore=GL08
         ...  # pragma: no cover
 
     def __setitem__(
         self,
-        index,
+        index: int | str | slice,
         data,
     ):
         """Set a block with a VTK data object.
@@ -671,7 +696,7 @@ class MultiBlock(
 
         """
         i: int = 0
-        name: Optional[str] = None
+        name: str | None = None
         if isinstance(index, str):
             try:
                 i = self.get_index_by_name(index)
@@ -684,7 +709,8 @@ class MultiBlock(
             for i, (idx, d) in enumerate(zip_longest(index_iter, data)):
                 if idx is None:
                     self.insert(
-                        index_iter[-1] + 1 + (i - len(index_iter)), d
+                        index_iter[-1] + 1 + (i - len(index_iter)),
+                        d,
                     )  # insert after last entry, increasing
                 elif d is None:
                     del self[index_iter[-1] + 1]  # delete next entry
@@ -714,7 +740,7 @@ class MultiBlock(
             name = f'Block-{i:02}'
         self.set_block_name(i, name)  # Note that this calls self.Modified()
 
-    def __delitem__(self, index: Union[int, str, slice]) -> None:
+    def __delitem__(self, index: int | str | slice) -> None:
         """Remove a block at the specified index."""
         if isinstance(index, slice):
             if index.indices(self.n_blocks)[2] > 0:
@@ -733,9 +759,9 @@ class MultiBlock(
         """Remove python reference to the dataset."""
         dataset = self[index]
         if hasattr(dataset, 'memory_address'):
-            self._refs.pop(dataset.memory_address, None)  # type: ignore
+            self._refs.pop(dataset.memory_address, None)  # type: ignore[union-attr]
 
-    def __iter__(self) -> 'MultiBlock':
+    def __iter__(self) -> MultiBlock:
         """Return the iterator across all blocks."""
         self._iter_n = 0
         return self
@@ -754,12 +780,9 @@ class MultiBlock(
         if not self.keys() == other.keys():
             return False
 
-        if any(self_mesh != other_mesh for self_mesh, other_mesh in zip(self, other)):
-            return False
+        return not any(self_mesh != other_mesh for self_mesh, other_mesh in zip(self, other))
 
-        return True
-
-    def __next__(self) -> Optional[_TypeMultiBlockLeaf]:
+    def __next__(self) -> _TypeMultiBlockLeaf | None:
         """Get the next block from the iterator."""
         if self._iter_n < self.n_blocks:
             result = self[self._iter_n]
@@ -767,7 +790,7 @@ class MultiBlock(
             return result
         raise StopIteration
 
-    def insert(self, index: int, dataset: _TypeMultiBlockLeaf, name: Optional[str] = None) -> None:
+    def insert(self, index: int, dataset: _TypeMultiBlockLeaf, name: str | None = None) -> None:
         """Insert data before index.
 
         Parameters
@@ -807,7 +830,7 @@ class MultiBlock(
         self[index] = dataset
         self.set_block_name(index, name)
 
-    def pop(self, index: Union[int, str] = -1) -> Optional[_TypeMultiBlockLeaf]:
+    def pop(self, index: int | str = -1) -> _TypeMultiBlockLeaf | None:
         """Pop off a block at the specified index.
 
         Parameters
@@ -897,9 +920,7 @@ class MultiBlock(
                 self[i].clean()
                 if self[i].n_blocks < 1:
                     null_blocks.append(i)
-            elif self[i] is None:
-                null_blocks.append(i)
-            elif empty and self[i].n_points < 1:
+            elif self[i] is None or empty and self[i].n_points < 1:
                 null_blocks.append(i)
         # Now remove the null/empty meshes
         null_blocks = np.array(null_blocks, dtype=int)
@@ -980,7 +1001,6 @@ class MultiBlock(
         # Note that `pyvista.MultiBlock` datasets currently don't have any meta.
         # This method is here for consistency with the rest of the API and
         # in case we add meta data to this pbject down the road.
-        pass
 
     def copy(self, deep=True):
         """Return a copy of the multiblock.
@@ -1034,8 +1054,11 @@ class MultiBlock(
             self.ShallowCopy(to_copy)
 
     def set_active_scalars(
-        self, name: Optional[str], preference: str = 'cell', allow_missing: bool = False
-    ) -> Tuple[FieldAssociation, np.ndarray]:  # type: ignore
+        self,
+        name: str | None,
+        preference: str = 'cell',
+        allow_missing: bool = False,
+    ) -> tuple[FieldAssociation, NumpyArray[float]]:
         """Find the scalars by name and appropriately set it as active.
 
         To deactivate any active scalars, pass ``None`` as the ``name``.
@@ -1069,12 +1092,14 @@ class MultiBlock(
         The number of components of the data must match.
 
         """
-        data_assoc: List[Tuple[FieldAssociation, np.ndarray, _TypeMultiBlockLeaf]] = []
+        data_assoc: list[tuple[FieldAssociation, NumpyArray[float], _TypeMultiBlockLeaf]] = []
         for block in self:
             if block is not None:
                 if isinstance(block, MultiBlock):
                     field, scalars = block.set_active_scalars(
-                        name, preference, allow_missing=allow_missing
+                        name,
+                        preference,
+                        allow_missing=allow_missing,
                     )
                 else:
                     try:
@@ -1083,9 +1108,9 @@ class MultiBlock(
                             field, scalars = FieldAssociation.NONE, pyvista_ndarray([])
                         else:
                             scalars = scalars_out
-                    except KeyError as err:
+                    except KeyError:
                         if not allow_missing:
-                            raise err
+                            raise
                         block.set_active_scalars(None, preference)
                         field, scalars = FieldAssociation.NONE, pyvista_ndarray([])
 
@@ -1108,9 +1133,9 @@ class MultiBlock(
                     break
 
         # Verify array consistency
-        dims: Set[int] = set()
-        dtypes: Set[np.dtype] = set()
-        for block in self:
+        dims: set[int] = set()
+        dtypes: set[np.dtype[Any]] = set()
+        for _ in self:
             for field, scalars, _ in data_assoc:
                 # only check for the active field association
                 if field != field_asc:
@@ -1173,7 +1198,7 @@ class MultiBlock(
         return dataset
 
     @property
-    def is_all_polydata(self) -> bool:  # numpydoc ignore=RT01
+    def is_all_polydata(self) -> bool:
         """Return ``True`` when all the blocks are :class:`pyvista.PolyData`.
 
         This method will recursively check if any internal blocks are also
@@ -1209,6 +1234,10 @@ class MultiBlock(
         if rgb:
             if scalars.ndim != 2 or scalars.shape[1] not in (3, 4):
                 raise ValueError('RGB array must be n_points/n_cells by 3/4 in shape.')
+            if dtype != np.uint8:
+                # uint8 is required by the mapper to display correctly
+                _validation.check_subdtype(scalars, (np.floating, np.integer), name='rgb scalars')
+                scalars_name = self._convert_to_uint8_rgb_scalars(data_attr, scalars_name)
         elif np.issubdtype(scalars.dtype, np.complexfloating):
             # Use only the real component if an array is complex
             scalars_name = self._convert_to_real_scalars(data_attr, scalars_name)
@@ -1225,7 +1254,7 @@ class MultiBlock(
                 if component >= scalars.shape[1] or component < 0:
                     raise ValueError(
                         'Component must be nonnegative and less than the '
-                        f'dimensionality of the scalars array: {scalars.shape[1]}'
+                        f'dimensionality of the scalars array: {scalars.shape[1]}',
                     )
             scalars_name = self._convert_to_single_component(data_attr, scalars_name, component)
 
@@ -1245,8 +1274,30 @@ class MultiBlock(
                     dattr.active_scalars_name = f'{scalars_name}-real'
         return f'{scalars_name}-real'
 
+    def _convert_to_uint8_rgb_scalars(self, data_attr: str, scalars_name: str):
+        """Convert rgb float or int scalars to uint8."""
+        for block in self:
+            if isinstance(block, MultiBlock):
+                block._convert_to_uint8_rgb_scalars(data_attr, scalars_name)
+            elif block is not None:
+                scalars = getattr(block, data_attr).get(scalars_name, None)
+                if scalars is not None:
+                    if np.issubdtype(scalars.dtype, np.floating):
+                        _validation.check_range(scalars, [0.0, 1.0], name='rgb float scalars')
+                        scalars = np.array(scalars, dtype=np.uint8) * 255
+                    elif np.issubdtype(scalars.dtype, np.integer):
+                        _validation.check_range(scalars, [0, 255], name='rgb int scalars')
+                        scalars = np.array(scalars, dtype=np.uint8)
+                    dattr = getattr(block, data_attr)
+                    dattr[f'{scalars_name}-uint8'] = scalars
+                    dattr.active_scalars_name = f'{scalars_name}-uint8'
+        return f'{scalars_name}-uint8'
+
     def _convert_to_single_component(
-        self, data_attr: str, scalars_name: str, component: Union[None, str]
+        self,
+        data_attr: str,
+        scalars_name: str,
+        component: None | str,
     ) -> str:
         """Convert multi-component scalars to a single component."""
         if component is None:
@@ -1289,3 +1340,27 @@ class MultiBlock(
         point_name = point_names.pop() if len(point_names) == 1 else None
         cell_name = cell_names.pop() if len(cell_names) == 1 else None
         return point_name, cell_name
+
+    def clear_all_data(self):
+        """Clear all data from all blocks."""
+        for block in self:
+            if isinstance(block, MultiBlock):
+                block.clear_all_data()
+            elif block is not None:
+                block.clear_data()
+
+    def clear_all_point_data(self):
+        """Clear all point data from all blocks."""
+        for block in self:
+            if isinstance(block, MultiBlock):
+                block.clear_all_point_data()
+            elif block is not None:
+                block.clear_point_data()
+
+    def clear_all_cell_data(self):
+        """Clear all cell data from all blocks."""
+        for block in self:
+            if isinstance(block, MultiBlock):
+                block.clear_all_cell_data()
+            elif block is not None:
+                block.clear_cell_data()
