@@ -1,31 +1,37 @@
 """Sub-classes for vtk.vtkRectilinearGrid and vtk.vtkImageData."""
+
+from __future__ import annotations
+
 from functools import wraps
 import pathlib
-from typing import Sequence, Tuple, Union
-import warnings
+from typing import TYPE_CHECKING
+from typing import ClassVar
+from typing import Sequence
+from typing import cast
 
 import numpy as np
 
 import pyvista
 
+if TYPE_CHECKING:
+    from pyvista.core._typing_core import NumpyArray
+
 from . import _vtk_core as _vtk
 from .dataset import DataSet
-from .errors import PyVistaDeprecationWarning
-from .filters import ImageDataFilters, RectilinearGridFilters, _get_output
-from .utilities.arrays import convert_array, raise_has_duplicates
-from .utilities.misc import abstract_class, assert_empty_kwargs
+from .filters import ImageDataFilters
+from .filters import RectilinearGridFilters
+from .filters import _get_output
+from .utilities.arrays import convert_array
+from .utilities.arrays import raise_has_duplicates
+from .utilities.misc import abstract_class
 
 
 @abstract_class
 class Grid(DataSet):
     """A class full of common methods for non-pointset grids."""
 
-    def __init__(self, *args, **kwargs):
-        """Initialize the grid."""
-        super().__init__()
-
     @property
-    def dimensions(self) -> Tuple[int, int, int]:  # numpydoc ignore=RT01
+    def dimensions(self) -> tuple[int, int, int]:
         """Return the grid's dimensions.
 
         These are effectively the number of points along each of the
@@ -66,7 +72,7 @@ class Grid(DataSet):
         return attrs
 
 
-class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
+class RectilinearGrid(Grid, RectilinearGridFilters, _vtk.vtkRectilinearGrid):
     """Dataset with variable spacing in the three coordinate directions.
 
     Can be initialized in several ways:
@@ -126,13 +132,25 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
 
     """
 
-    _WRITERS = {'.vtk': _vtk.vtkRectilinearGridWriter, '.vtr': _vtk.vtkXMLRectilinearGridWriter}
+    _WRITERS: ClassVar[
+        dict[
+            str,
+            type[_vtk.vtkRectilinearGridWriter | _vtk.vtkXMLRectilinearGridWriter],
+        ]
+    ] = {
+        '.vtk': _vtk.vtkRectilinearGridWriter,
+        '.vtr': _vtk.vtkXMLRectilinearGridWriter,
+    }
 
     def __init__(
-        self, *args, check_duplicates=False, deep=False, **kwargs
+        self,
+        *args,
+        check_duplicates=False,
+        deep=False,
+        **kwargs,
     ):  # numpydoc ignore=PR01,RT01
         """Initialize the rectilinear grid."""
-        super().__init__()
+        super().__init__(**kwargs)
 
         if len(args) == 1:
             if isinstance(args[0], _vtk.vtkRectilinearGrid):
@@ -150,10 +168,7 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
         elif len(args) == 3 or len(args) == 2:
             arg0_is_arr = isinstance(args[0], (np.ndarray, Sequence))
             arg1_is_arr = isinstance(args[1], (np.ndarray, Sequence))
-            if len(args) == 3:
-                arg2_is_arr = isinstance(args[2], (np.ndarray, Sequence))
-            else:
-                arg2_is_arr = False
+            arg2_is_arr = isinstance(args[2], (np.ndarray, Sequence)) if len(args) == 3 else False
 
             if all([arg0_is_arr, arg1_is_arr, arg2_is_arr]):
                 self._from_arrays(
@@ -164,7 +179,10 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
                 )
             elif all([arg0_is_arr, arg1_is_arr]):
                 self._from_arrays(
-                    np.asanyarray(args[0]), np.asanyarray(args[1]), None, check_duplicates
+                    np.asanyarray(args[0]),
+                    np.asanyarray(args[1]),
+                    None,
+                    check_duplicates,
                 )
             else:
                 raise TypeError("Arguments not understood by `RectilinearGrid`.")
@@ -179,10 +197,14 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
 
     def _update_dimensions(self):
         """Update the dimensions if coordinates have changed."""
-        return self.SetDimensions(len(self.x), len(self.y), len(self.z))
+        self.SetDimensions(len(self.x), len(self.y), len(self.z))
 
     def _from_arrays(
-        self, x: np.ndarray, y: np.ndarray, z: np.ndarray, check_duplicates: bool = False
+        self,
+        x: NumpyArray[float],
+        y: NumpyArray[float],
+        z: NumpyArray[float],
+        check_duplicates: bool = False,
     ):
         """Create VTK rectilinear grid directly from numpy arrays.
 
@@ -230,7 +252,7 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
         self._update_dimensions()
 
     @property
-    def meshgrid(self) -> list:  # numpydoc ignore=RT01
+    def meshgrid(self) -> tuple[NumpyArray[float], NumpyArray[float], NumpyArray[float]]:
         """Return a meshgrid of numpy arrays for this mesh.
 
         This simply returns a :func:`numpy.meshgrid` of the
@@ -239,14 +261,21 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
 
         Returns
         -------
-        list[numpy.ndarray]
-            List of numpy arrays representing the points of this mesh.
+        tuple[numpy.ndarray, numpy.ndarray, numpy.ndarray]
+            Tuple of numpy arrays representing the points of this mesh.
 
         """
-        return np.meshgrid(self.x, self.y, self.z, indexing='ij')
+        # Converting to tuple needed to be consistent type across numpy version
+        # Remove when support is dropped for numpy 1.x
+        # We also know this is 3-length so make it so in typing
+        out = tuple(np.meshgrid(self.x, self.y, self.z, indexing='ij'))
+        # Python 3.8 does not allow subscripting tuple, but only used for type checking
+        if TYPE_CHECKING:  # pragma: no cover
+            out = cast(tuple[NumpyArray[float], NumpyArray[float], NumpyArray[float]], out)
+        return out
 
-    @property  # type: ignore
-    def points(self) -> np.ndarray:  # type: ignore  # numpydoc ignore=RT01
+    @property  # type: ignore[explicit-override, override]
+    def points(self) -> NumpyArray[float]:
         """Return a copy of the points as an ``(n, 3)`` numpy array.
 
         Returns
@@ -292,11 +321,11 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
         raise AttributeError(
             "The points cannot be set. The points of "
             "`RectilinearGrid` are defined in each axial direction. Please "
-            "use the `x`, `y`, and `z` setters individually."
+            "use the `x`, `y`, and `z` setters individually.",
         )
 
     @property
-    def x(self) -> np.ndarray:  # numpydoc ignore=RT01
+    def x(self) -> NumpyArray[float]:
         """Return or set the coordinates along the X-direction.
 
         Returns
@@ -327,13 +356,13 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
         return convert_array(self.GetXCoordinates())
 
     @x.setter
-    def x(self, coords: Sequence):  # numpydoc ignore=GL08
+    def x(self, coords: Sequence[float]):  # numpydoc ignore=GL08
         self.SetXCoordinates(convert_array(coords))
         self._update_dimensions()
         self.Modified()
 
     @property
-    def y(self) -> np.ndarray:  # numpydoc ignore=RT01
+    def y(self) -> NumpyArray[float]:
         """Return or set the coordinates along the Y-direction.
 
         Returns
@@ -364,13 +393,13 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
         return convert_array(self.GetYCoordinates())
 
     @y.setter
-    def y(self, coords: Sequence):  # numpydoc ignore=GL08
+    def y(self, coords: Sequence[float]):  # numpydoc ignore=GL08
         self.SetYCoordinates(convert_array(coords))
         self._update_dimensions()
         self.Modified()
 
     @property
-    def z(self) -> np.ndarray:  # numpydoc ignore=RT01
+    def z(self) -> NumpyArray[float]:
         """Return or set the coordinates along the Z-direction.
 
         Returns
@@ -401,12 +430,12 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
         return convert_array(self.GetZCoordinates())
 
     @z.setter
-    def z(self, coords: Sequence):  # numpydoc ignore=GL08
+    def z(self, coords: Sequence[float]):  # numpydoc ignore=GL08
         self.SetZCoordinates(convert_array(coords))
         self._update_dimensions()
         self.Modified()
 
-    @Grid.dimensions.setter  # type: ignore
+    @Grid.dimensions.setter  # type: ignore[attr-defined]
     def dimensions(self, _dims):  # numpydoc ignore=GL08
         """Set Dimensions.
 
@@ -418,10 +447,10 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
         """
         raise AttributeError(
             "The dimensions of a `RectilinearGrid` are implicitly "
-            "defined and thus cannot be set."
+            "defined and thus cannot be set.",
         )
 
-    def cast_to_structured_grid(self) -> 'pyvista.StructuredGrid':
+    def cast_to_structured_grid(self) -> pyvista.StructuredGrid:
         """Cast this rectilinear grid to a structured grid.
 
         Returns
@@ -436,7 +465,7 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid, RectilinearGridFilters):
         return _get_output(alg)
 
 
-class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
+class ImageData(Grid, ImageDataFilters, _vtk.vtkImageData):
     """Models datasets with uniform spacing in the three coordinate directions.
 
     Can be initialized in one of several ways:
@@ -517,61 +546,22 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
 
     """
 
-    _WRITERS = {'.vtk': _vtk.vtkDataSetWriter, '.vti': _vtk.vtkXMLImageDataWriter}
+    _WRITERS: ClassVar[dict[str, type[_vtk.vtkDataSetWriter | _vtk.vtkXMLImageDataWriter]]] = {
+        '.vtk': _vtk.vtkDataSetWriter,
+        '.vti': _vtk.vtkXMLImageDataWriter,
+    }
 
     def __init__(
         self,
         uinput=None,
-        *args,
         dimensions=None,
         spacing=(1.0, 1.0, 1.0),
         origin=(0.0, 0.0, 0.0),
         deep=False,
-        **kwargs,
     ):
         """Initialize the uniform grid."""
         super().__init__()
 
-        # permit old behavior
-        if isinstance(uinput, Sequence) and not isinstance(uinput, str):
-            # Deprecated on v0.37.0, estimated removal on v0.40.0
-            warnings.warn(
-                "Behavior of pyvista.ImageData has changed. First argument must be "
-                "either a ``vtk.vtkImageData`` or path.",
-                PyVistaDeprecationWarning,
-            )
-            dimensions = uinput
-            uinput = None
-
-        if dimensions is None and 'dims' in kwargs:
-            dimensions = kwargs.pop('dims')
-            # Deprecated on v0.37.0, estimated removal on v0.40.0
-            warnings.warn(
-                '`dims` argument is deprecated. Please use `dimensions`.', PyVistaDeprecationWarning
-            )
-        assert_empty_kwargs(**kwargs)
-
-        if args:
-            # Deprecated on v0.37.0, estimated removal on v0.40.0
-            warnings.warn(
-                "Behavior of pyvista.ImageData has changed. Use keyword arguments "
-                "to specify dimensions, spacing, and origin. For example:\n\n"
-                "    >>> grid = pv.ImageData(\n"
-                "    ...     dimensions=(10, 10, 10),\n"
-                "    ...     spacing=(2, 1, 5),\n"
-                "    ...     origin=(10, 35, 50),\n"
-                "    ... )\n",
-                PyVistaDeprecationWarning,
-            )
-            origin = args[0]
-            if len(args) > 1:
-                spacing = args[1]
-            if len(args) > 2:
-                raise ValueError(
-                    "Too many additional arguments specified for ImageData. "
-                    f"Accepts at most 2, and {len(args)} have been input."
-                )
-
         # first argument must be either vtkImageData or a path
         if uinput is not None:
             if isinstance(uinput, _vtk.vtkImageData):
@@ -590,7 +580,7 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
                     "    ...     dimensions=(10, 10, 10),\n"
                     "    ...     spacing=(2, 1, 5),\n"
                     "    ...     origin=(10, 35, 50),\n"
-                    "    ... )\n"
+                    "    ... )\n",
                 )
         elif dimensions is not None:
             self._from_specs(dimensions, spacing, origin)
@@ -604,7 +594,10 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         return DataSet.__str__(self)
 
     def _from_specs(
-        self, dims: Sequence[int], spacing=(1.0, 1.0, 1.0), origin=(0.0, 0.0, 0.0)
+        self,
+        dims: Sequence[int],
+        spacing=(1.0, 1.0, 1.0),
+        origin=(0.0, 0.0, 0.0),
     ):  # numpydoc ignore=PR01,RT01
         """Create VTK image data directly from numpy arrays.
 
@@ -631,8 +624,8 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         self.SetOrigin(xo, yo, zo)
         self.spacing = (spacing[0], spacing[1], spacing[2])
 
-    @property  # type: ignore
-    def points(self) -> np.ndarray:  # type: ignore  # numpydoc ignore=RT01
+    @property  # type: ignore[explicit-override, override]
+    def points(self) -> NumpyArray[float]:
         """Build a copy of the implicitly defined points as a numpy array.
 
         Returns
@@ -685,11 +678,11 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         raise AttributeError(
             "The points cannot be set. The points of "
             "`ImageData`/`vtkImageData` are implicitly defined by the "
-            "`origin`, `spacing`, and `dimensions` of the grid."
+            "`origin`, `spacing`, and `dimensions` of the grid.",
         )
 
     @property
-    def x(self) -> np.ndarray:  # numpydoc ignore=RT01
+    def x(self) -> NumpyArray[float]:  # numpydoc ignore=RT01
         """Return all the X points.
 
         Examples
@@ -703,7 +696,7 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         return self.points[:, 0]
 
     @property
-    def y(self) -> np.ndarray:  # numpydoc ignore=RT01
+    def y(self) -> NumpyArray[float]:  # numpydoc ignore=RT01
         """Return all the Y points.
 
         Examples
@@ -717,7 +710,7 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         return self.points[:, 1]
 
     @property
-    def z(self) -> np.ndarray:  # numpydoc ignore=RT01
+    def z(self) -> NumpyArray[float]:  # numpydoc ignore=RT01
         """Return all the Z points.
 
         Examples
@@ -731,7 +724,7 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         return self.points[:, 2]
 
     @property
-    def origin(self) -> Tuple[float]:  # numpydoc ignore=RT01
+    def origin(self) -> tuple[float]:  # numpydoc ignore=RT01
         """Return the origin of the grid (bottom southwest corner).
 
         Examples
@@ -764,12 +757,12 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         return self.GetOrigin()
 
     @origin.setter
-    def origin(self, origin: Sequence[Union[float, int]]):  # numpydoc ignore=GL08
+    def origin(self, origin: Sequence[float | int]):  # numpydoc ignore=GL08
         self.SetOrigin(origin[0], origin[1], origin[2])
         self.Modified()
 
     @property
-    def spacing(self) -> Tuple[float, float, float]:  # numpydoc ignore=RT01
+    def spacing(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
         """Return or set the spacing for each axial direction.
 
         Notes
@@ -797,7 +790,7 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         return self.GetSpacing()
 
     @spacing.setter
-    def spacing(self, spacing: Sequence[Union[float, int]]):  # numpydoc ignore=GL08
+    def spacing(self, spacing: Sequence[float | int]):  # numpydoc ignore=GL08
         if min(spacing) < 0:
             raise ValueError(f"Spacing must be non-negative, got {spacing}")
         self.SetSpacing(*spacing)
@@ -810,7 +803,7 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         attrs.append(("Spacing", self.spacing, fmt))
         return attrs
 
-    def cast_to_structured_grid(self) -> 'pyvista.StructuredGrid':
+    def cast_to_structured_grid(self) -> pyvista.StructuredGrid:
         """Cast this uniform grid to a structured grid.
 
         Returns
@@ -824,7 +817,7 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         alg.Update()
         return _get_output(alg)
 
-    def cast_to_rectilinear_grid(self) -> 'RectilinearGrid':
+    def cast_to_rectilinear_grid(self) -> RectilinearGrid:
         """Cast this uniform grid to a rectilinear grid.
 
         Returns
@@ -835,11 +828,10 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         """
 
         def gen_coords(i):  # numpydoc ignore=GL08
-            coords = (
+            return (
                 np.cumsum(np.insert(np.full(self.dimensions[i] - 1, self.spacing[i]), 0, 0))
                 + self.origin[i]
             )
-            return coords
 
         xcoords = gen_coords(0)
         ycoords = gen_coords(1)
@@ -852,7 +844,7 @@ class ImageData(_vtk.vtkImageData, Grid, ImageDataFilters):
         return grid
 
     @property
-    def extent(self) -> tuple:  # numpydoc ignore=RT01
+    def extent(self) -> tuple[int, int, int, int, int, int]:  # numpydoc ignore=RT01
         """Return or set the extent of the ImageData.
 
         The extent is simply the first and last indices for each of the three axes.
