@@ -1,6 +1,7 @@
 """Module containing geometry helper functions."""
 
-import collections.abc
+from __future__ import annotations
+
 import os
 import sys
 from typing import Sequence
@@ -64,7 +65,7 @@ def voxelize(mesh, density=None, check_surface=True):
         density = mesh.length / 100
     if isinstance(density, (int, float, np.number)):
         density_x, density_y, density_z = [density] * 3
-    elif isinstance(density, (collections.abc.Sequence, np.ndarray)):
+    elif isinstance(density, (Sequence, np.ndarray)):
         density_x, density_y, density_z = density
     else:
         raise TypeError(f'Invalid density {density!r}, expected number or array-like.')
@@ -95,8 +96,7 @@ def voxelize(mesh, density=None, check_surface=True):
     mask = selection.point_data['SelectedPoints'].view(np.bool_)
 
     # extract cells from point indices
-    vox = ugrid.extract_points(mask)
-    return vox
+    return ugrid.extract_points(mask)
 
 
 def voxelize_volume(mesh, density=None, check_surface=True):
@@ -171,7 +171,7 @@ def voxelize_volume(mesh, density=None, check_surface=True):
         density = mesh.length / 100
     if isinstance(density, (int, float, np.number)):
         density_x, density_y, density_z = [density] * 3
-    elif isinstance(density, (collections.abc.Sequence, np.ndarray)):
+    elif isinstance(density, (Sequence, np.ndarray)):
         density_x, density_y, density_z = density
     else:
         raise TypeError(f'Invalid density {density!r}, expected number or array-like.')
@@ -431,7 +431,7 @@ def merge(
     >>> mesh.plot()
 
     """
-    if not isinstance(datasets, collections.abc.Sequence):
+    if not isinstance(datasets, Sequence):
         raise TypeError(f"Expected a sequence, got {type(datasets).__name__}")
 
     if len(datasets) < 1:
@@ -519,7 +519,7 @@ def sample_function(
     bounds: Sequence[float] = (-1.0, 1.0, -1.0, 1.0, -1.0, 1.0),
     dim: Sequence[int] = (50, 50, 50),
     compute_normals: bool = False,
-    output_type: np.dtype = np.double,  # type: ignore
+    output_type: np.dtype = np.double,  # type: ignore[assignment, type-arg]
     capping: bool = False,
     cap_value: float = sys.float_info.max,
     scalar_arr_name: str = "scalars",
