@@ -1,7 +1,8 @@
 """Contains a dictionary that maps file extensions to VTK readers."""
 
-import os
-import pathlib
+from __future__ import annotations
+
+from pathlib import Path
 import warnings
 
 import numpy as np
@@ -13,7 +14,7 @@ from pyvista.core.errors import PyVistaDeprecationWarning
 from .observers import Observer
 
 
-def set_pickle_format(format: str):
+def set_pickle_format(format: str):  # noqa: A002
     """Set the format used to serialize :class:`pyvista.DataObject` when pickled.
 
     Parameters
@@ -28,12 +29,12 @@ def set_pickle_format(format: str):
 
     """
     supported = {'xml', 'legacy'}
-    format = format.lower()
-    if format not in supported:
+    format_ = format.lower()
+    if format_ not in supported:
         raise ValueError(
-            f'Unsupported pickle format `{format}`. Valid options are `{"`, `".join(supported)}`.'
+            f'Unsupported pickle format `{format_}`. Valid options are `{"`, `".join(supported)}`.',
         )
-    pyvista.PICKLE_FORMAT = format
+    pyvista.PICKLE_FORMAT = format_
 
 
 def _get_ext_force(filename, force_ext=None):
@@ -51,7 +52,7 @@ def get_ext(filename):
 
     Parameters
     ----------
-    filename : str
+    filename : str, Path
         The filename from which to extract the extension.
 
     Returns
@@ -61,10 +62,13 @@ def get_ext(filename):
         extension is returned as well.
 
     """
-    base, ext = os.path.splitext(filename)
+    path = Path(filename)
+    base = str(path.parent / path.stem)
+    ext = path.suffix
     ext = ext.lower()
     if ext == ".gz":
-        ext_pre = os.path.splitext(base)[1].lower()
+        path = Path(base)
+        ext_pre = path.suffix.lower()
         ext = f"{ext_pre}{ext}"
     return ext
 
@@ -119,7 +123,7 @@ def read(filename, force_ext=None, file_format=None, progress_bar=False):
 
     Parameters
     ----------
-    filename : str
+    filename : str, Path
         The string path to the file to read. If a list of files is
         given, a :class:`pyvista.MultiBlock` dataset is returned with
         each file being a separate block in the dataset.
@@ -163,14 +167,11 @@ def read(filename, force_ext=None, file_format=None, progress_bar=False):
     if isinstance(filename, (list, tuple)):
         multi = pyvista.MultiBlock()
         for each in filename:
-            if isinstance(each, (str, pathlib.Path)):
-                name = os.path.basename(str(each))
-            else:
-                name = None
+            name = Path(each).name if isinstance(each, (str, Path)) else None
             multi.append(read(each, file_format=file_format), name)
         return multi
-    filename = os.path.abspath(os.path.expanduser(str(filename)))
-    if not os.path.isfile(filename):
+    filename = Path(filename).expanduser().resolve()
+    if not filename.is_file() and not filename.is_dir():
         raise FileNotFoundError(f'File ({filename}) not found')
 
     # Read file using meshio.read if file_format is present
@@ -203,7 +204,7 @@ def read(filename, force_ext=None, file_format=None, progress_bar=False):
             warnings.warn(
                 f"The VTK reader `{reader.reader.GetClassName()}` in pyvista reader `{reader}` raised an error"
                 "while reading the file.\n"
-                f'\t"{observer.get_message()}"'
+                f'\t"{observer.get_message()}"',
             )
         return mesh
 
@@ -257,17 +258,17 @@ def read_texture(filename, progress_bar=False):
     --------
     Read in an example jpg map file as a texture.
 
-    >>> import os
+    >>> from pathlib import Path
     >>> import pyvista as pv
     >>> from pyvista import examples
-    >>> os.path.basename(examples.mapfile)
+    >>> Path(examples.mapfile).name
     '2k_earth_daymap.jpg'
     >>> texture = pv.read_texture(examples.mapfile)
     >>> type(texture)
     <class 'pyvista.plotting.texture.Texture'>
 
     """
-    filename = os.path.abspath(os.path.expanduser(filename))
+    filename = Path(filename).expanduser().resolve()
     try:
         # initialize the reader using the extension to find it
 
@@ -295,7 +296,7 @@ def read_exodus(
 
     Parameters
     ----------
-    filename : str
+    filename : str, Path
         The path to the exodus file to read.
 
     animate_mode_shapes : bool, default: True
@@ -343,7 +344,10 @@ def read_exodus(
         from vtk import vtkExodusIIReader
 
     reader = vtkExodusIIReader()
-    reader.SetFileName(filename)
+    if pyvista.vtk_version_info < (9, 1, 0):  # pragma no cover
+        reader.SetFileName(str(filename))
+    else:
+        reader.SetFileName(filename)
     reader.UpdateInformation()
     reader.SetAnimateModeShapes(animate_mode_shapes)
     reader.SetApplyDisplacements(apply_displacements)
@@ -414,7 +418,8 @@ def from_meshio(mesh):
 
     """
     try:  # meshio<5.0 compatibility
-        from meshio.vtk._vtk import meshio_to_vtk_type, vtk_type_to_numnodes
+        from meshio.vtk._vtk import meshio_to_vtk_type
+        from meshio.vtk._vtk import vtk_type_to_numnodes
     except ImportError:  # pragma: no cover
         from meshio._vtk_common import meshio_to_vtk_type
         from meshio.vtk._vtk_42 import vtk_type_to_numnodes
@@ -423,10 +428,27 @@ def from_meshio(mesh):
     cells = []
     cell_type = []
     for c in mesh.cells:
-        vtk_type = meshio_to_vtk_type[c.type]
-        numnodes = vtk_type_to_numnodes[vtk_type]
-        fill_values = np.full((len(c.data), 1), numnodes, dtype=c.data.dtype)
-        cells.append(np.hstack((fill_values, c.data)).ravel())
+        if c.type.startswith("polyhedron"):
+            vtk_type = meshio_to_vtk_type["polyhedron"]
+
+            for cell in c.data:
+                connectivity = [len(cell)]
+                for face in cell:
+                    connectivity += [len(face), *face]
+
+                connectivity.insert(0, len(connectivity))
+                cells.append(connectivity)
+
+        else:
+            vtk_type = meshio_to_vtk_type[c.type]
+            numnodes = vtk_type_to_numnodes[vtk_type]
+            if numnodes == -1:
+                # Count nodes in each cell
+                fill_values = np.array([[len(data)] for data in c.data], dtype=c.data.dtype)
+            else:
+                fill_values = np.full((len(c.data), 1), numnodes, dtype=c.data.dtype)
+            cells.append(np.hstack((fill_values, c.data)).ravel())
+
         cell_type += [vtk_type] * len(c.data)
 
     # Extract cell data from meshio.Mesh object
@@ -435,7 +457,7 @@ def from_meshio(mesh):
     # Create pyvista.UnstructuredGrid object
     points = mesh.points
 
-    # convert to 3D if points are 2D
+    # Convert to 3D if points are 2D
     if points.shape[1] == 2:
         zero_points = np.zeros((len(points), 1), dtype=points.dtype)
         points = np.hstack((points, zero_points))
@@ -486,7 +508,7 @@ def read_meshio(filename, file_format=None):
         raise ImportError("To use this feature install meshio with:\n\npip install meshio")
 
     # Make sure relative paths will work
-    filename = os.path.abspath(os.path.expanduser(str(filename)))
+    filename = Path(filename).expanduser().resolve()
     # Read mesh file
     mesh = meshio.read(filename, file_format)
     return from_meshio(mesh)
@@ -528,11 +550,11 @@ def save_meshio(filename, mesh, file_format=None, **kwargs):
 
     try:  # for meshio<5.0 compatibility
         from meshio.vtk._vtk import vtk_to_meshio_type
-    except:  # noqa: E722 pragma: no cover
+    except:  # pragma: no cover
         from meshio._vtk_common import vtk_to_meshio_type
 
     # Make sure relative paths will work
-    filename = os.path.abspath(os.path.expanduser(str(filename)))
+    filename = Path(filename).expanduser().resolve()
 
     # Cast to pyvista.UnstructuredGrid
     if not isinstance(mesh, pyvista.UnstructuredGrid):
@@ -552,36 +574,42 @@ def save_meshio(filename, mesh, file_format=None, **kwargs):
     # Get cells
     cells = []
     c = 0
-    for offset, cell_type in zip(vtk_offset, vtk_cell_type):
-        numnodes = vtk_cells[offset + c]
-        cell = vtk_cells[offset + 1 + c : offset + 1 + c + numnodes]
-        c += 1
-        cell = (
-            cell
-            if cell_type not in pixel_voxel
-            else cell[[0, 1, 3, 2]]
-            if cell_type == 8
-            else cell[[0, 1, 3, 2, 4, 5, 7, 6]]
-        )
-        cell_type = cell_type if cell_type not in pixel_voxel else cell_type + 1
-        cell_type = vtk_to_meshio_type[cell_type] if cell_type != 7 else f"polygon{numnodes}"
+    for i, (offset, cell_type) in enumerate(zip(vtk_offset, vtk_cell_type)):
+        if cell_type == 42:
+            cell_ = mesh.get_cell(i)
+            cell = [face.point_ids for face in cell_.faces]
+            cell_type = f"polyhedron{cell_.n_points}"
+
+        else:
+            numnodes = vtk_cells[offset + c]
+            cell = vtk_cells[offset + 1 + c : offset + 1 + c + numnodes]
+            c += 1
+            cell = (
+                cell
+                if cell_type not in pixel_voxel
+                else cell[[0, 1, 3, 2]]
+                if cell_type == 8
+                else cell[[0, 1, 3, 2, 4, 5, 7, 6]]
+            )
+            cell_type = cell_type if cell_type not in pixel_voxel else cell_type + 1
+            cell_type = vtk_to_meshio_type[cell_type]
 
         if len(cells) > 0 and cells[-1][0] == cell_type:
             cells[-1][1].append(cell)
         else:
             cells.append((cell_type, [cell]))
 
-    for k, c in enumerate(cells):
-        cells[k] = (c[0], np.array(c[1]))
-
     # Get point data
     point_data = {k.replace(" ", "_"): v for k, v in mesh.point_data.items()}
 
     # Get cell data
     vtk_cell_data = mesh.cell_data
-    n_cells = np.cumsum([len(c[1]) for c in cells[:-1]])
+    indices = np.insert(np.cumsum([len(c[1]) for c in cells]), 0, 0)
     cell_data = (
-        {k.replace(" ", "_"): np.split(v, n_cells) for k, v in vtk_cell_data.items()}
+        {
+            k.replace(" ", "_"): [v[i1:i2] for i1, i2 in zip(indices[:-1], indices[1:])]
+            for k, v in vtk_cell_data.items()
+        }
         if vtk_cell_data
         else {}
     )
@@ -599,7 +627,7 @@ def save_meshio(filename, mesh, file_format=None, **kwargs):
 
 
 def _process_filename(filename):
-    return os.path.abspath(os.path.expanduser(str(filename)))
+    return Path(filename).expanduser().resolve()
 
 
 def _try_imageio_imread(filename):
@@ -607,7 +635,7 @@ def _try_imageio_imread(filename):
 
     Parameters
     ----------
-    filename : str
+    filename : str, Path
         Name of the file to read using ``imageio``.
 
     Returns
@@ -628,7 +656,7 @@ def _try_imageio_imread(filename):
         raise ModuleNotFoundError(
             'Problem reading the image with VTK. Install imageio to try to read the '
             'file using imageio with:\n\n'
-            '   pip install imageio'
+            '   pip install imageio',
         ) from None
 
     return imread(filename)
