@@ -1,5 +1,7 @@
 """Module managing parametric objects."""
 
+from __future__ import annotations
+
 from math import pi
 import warnings
 
@@ -114,7 +116,7 @@ def KochanekSpline(points, tension=None, bias=None, continuity=None, n_points=No
     check_valid_vector(tension, "tension")
     if not np.all(np.abs(tension) <= 1.0):
         raise ValueError(
-            "The absolute value of all values of the tension array elements must be <= 1.0 "
+            "The absolute value of all values of the tension array elements must be <= 1.0 ",
         )
 
     if bias is None:
@@ -122,7 +124,7 @@ def KochanekSpline(points, tension=None, bias=None, continuity=None, n_points=No
     check_valid_vector(bias, "bias")
     if not np.all(np.abs(bias) <= 1.0):
         raise ValueError(
-            "The absolute value of all values of the bias array elements must be <= 1.0 "
+            "The absolute value of all values of the bias array elements must be <= 1.0 ",
         )
 
     if continuity is None:
@@ -130,7 +132,7 @@ def KochanekSpline(points, tension=None, bias=None, continuity=None, n_points=No
     check_valid_vector(continuity, "continuity")
     if not np.all(np.abs(continuity) <= 1.0):
         raise ValueError(
-            "The absolute value of all values continuity array elements must be <= 1.0 "
+            "The absolute value of all values continuity array elements must be <= 1.0 ",
         )
 
     spline_function = _vtk.vtkParametricSpline()
@@ -1121,7 +1123,7 @@ def ParametricSuperEllipsoid(xradius=None, yradius=None, zradius=None, n1=None,
         The scaling factor for the z-axis.
 
     n1 : float, default: 1
-        The "squareness" parameter in the z axis.
+        The "squareness" parameter in the z-axis.
 
     n2 : float, default: 1
         The "squareness" parameter in the x-y plane.
@@ -1388,7 +1390,12 @@ def parametric_keywords(
 
 
 def surface_from_para(
-    parametric_function, u_res=100, v_res=100, w_res=100, clean=False, texture_coordinates=False
+    parametric_function,
+    u_res=100,
+    v_res=100,
+    w_res=100,
+    clean=False,
+    texture_coordinates=False,
 ):
     """Construct a mesh from a parametric function.
 
