@@ -1,5 +1,7 @@
 """Downloadable datasets of 3D Celestial Bodies."""
 
+from __future__ import annotations
+
 import numpy as np
 
 import pyvista
@@ -74,10 +76,11 @@ def load_sun(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no c
     >>> pl.show()
 
     """
-    sphere = _sphere_with_texture_map(
-        radius=radius, lat_resolution=lat_resolution, lon_resolution=lon_resolution
+    return _sphere_with_texture_map(
+        radius=radius,
+        lat_resolution=lat_resolution,
+        lon_resolution=lon_resolution,
     )
-    return sphere
 
 
 def load_moon(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no cover
@@ -114,10 +117,11 @@ def load_moon(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no
     >>> pl.show()
 
     """
-    sphere = _sphere_with_texture_map(
-        radius=radius, lat_resolution=lat_resolution, lon_resolution=lon_resolution
+    return _sphere_with_texture_map(
+        radius=radius,
+        lat_resolution=lat_resolution,
+        lon_resolution=lon_resolution,
     )
-    return sphere
 
 
 def load_mercury(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no cover
@@ -154,10 +158,11 @@ def load_mercury(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma:
     >>> pl.show()
 
     """
-    sphere = _sphere_with_texture_map(
-        radius=radius, lat_resolution=lat_resolution, lon_resolution=lon_resolution
+    return _sphere_with_texture_map(
+        radius=radius,
+        lat_resolution=lat_resolution,
+        lon_resolution=lon_resolution,
     )
-    return sphere
 
 
 def load_venus(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no cover
@@ -194,10 +199,11 @@ def load_venus(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no
     >>> pl.show()
 
     """
-    sphere = _sphere_with_texture_map(
-        radius=radius, lat_resolution=lat_resolution, lon_resolution=lon_resolution
+    return _sphere_with_texture_map(
+        radius=radius,
+        lat_resolution=lat_resolution,
+        lon_resolution=lon_resolution,
     )
-    return sphere
 
 
 def load_earth(radius=1.0, lat_resolution=50, lon_resolution=100):
@@ -234,10 +240,11 @@ def load_earth(radius=1.0, lat_resolution=50, lon_resolution=100):
     >>> pl.show()
 
     """
-    sphere = _sphere_with_texture_map(
-        radius=radius, lat_resolution=lat_resolution, lon_resolution=lon_resolution
+    return _sphere_with_texture_map(
+        radius=radius,
+        lat_resolution=lat_resolution,
+        lon_resolution=lon_resolution,
     )
-    return sphere
 
 
 def load_mars(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no cover
@@ -274,10 +281,11 @@ def load_mars(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no
     >>> pl.show()
 
     """
-    sphere = _sphere_with_texture_map(
-        radius=radius, lat_resolution=lat_resolution, lon_resolution=lon_resolution
+    return _sphere_with_texture_map(
+        radius=radius,
+        lat_resolution=lat_resolution,
+        lon_resolution=lon_resolution,
     )
-    return sphere
 
 
 def load_jupiter(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no cover
@@ -314,10 +322,11 @@ def load_jupiter(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma:
     >>> pl.show()
 
     """
-    sphere = _sphere_with_texture_map(
-        radius=radius, lat_resolution=lat_resolution, lon_resolution=lon_resolution
+    return _sphere_with_texture_map(
+        radius=radius,
+        lat_resolution=lat_resolution,
+        lon_resolution=lon_resolution,
     )
-    return sphere
 
 
 def load_saturn(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no cover
@@ -354,10 +363,11 @@ def load_saturn(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: n
     >>> pl.show()
 
     """
-    sphere = _sphere_with_texture_map(
-        radius=radius, lat_resolution=lat_resolution, lon_resolution=lon_resolution
+    return _sphere_with_texture_map(
+        radius=radius,
+        lat_resolution=lat_resolution,
+        lon_resolution=lon_resolution,
     )
-    return sphere
 
 
 def load_saturn_rings(inner=0.25, outer=0.5, c_res=6):  # pragma: no cover
@@ -438,10 +448,11 @@ def load_uranus(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: n
     >>> pl.show()
 
     """
-    sphere = _sphere_with_texture_map(
-        radius=radius, lat_resolution=lat_resolution, lon_resolution=lon_resolution
+    return _sphere_with_texture_map(
+        radius=radius,
+        lat_resolution=lat_resolution,
+        lon_resolution=lon_resolution,
     )
-    return sphere
 
 
 def load_neptune(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no cover
@@ -478,10 +489,11 @@ def load_neptune(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma:
     >>> pl.show()
 
     """
-    sphere = _sphere_with_texture_map(
-        radius=radius, lat_resolution=lat_resolution, lon_resolution=lon_resolution
+    return _sphere_with_texture_map(
+        radius=radius,
+        lat_resolution=lat_resolution,
+        lon_resolution=lon_resolution,
     )
-    return sphere
 
 
 def load_pluto(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no cover
@@ -518,10 +530,11 @@ def load_pluto(radius=1.0, lat_resolution=50, lon_resolution=100):  # pragma: no
     >>> pl.show()
 
     """
-    sphere = _sphere_with_texture_map(
-        radius=radius, lat_resolution=lat_resolution, lon_resolution=lon_resolution
+    return _sphere_with_texture_map(
+        radius=radius,
+        lat_resolution=lat_resolution,
+        lon_resolution=lon_resolution,
     )
-    return sphere
 
 
 def download_sun_surface(texture=False, load=True):  # pragma: no cover
