@@ -1,5 +1,12 @@
 """Wrap vtkLookupTable."""
-from typing import Any, Optional, Tuple, Union
+
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+from typing import Any
+from typing import Tuple
+from typing import Union
+from typing import cast
 
 import numpy as np
 
@@ -8,15 +15,18 @@ from pyvista.core.utilities.arrays import convert_array
 from pyvista.core.utilities.misc import no_new_attr
 
 from . import _vtk
-from ._typing import ColorLike
-from .colors import Color, get_cmap_safe
+from .colors import Color
+from .colors import get_cmap_safe
 from .tools import opacity_transfer_function
 
+if TYPE_CHECKING:  # pragma: no cover
+    from ._typing import ColorLike
+
 RAMP_MAP = {0: 'linear', 1: 's-curve', 2: 'sqrt'}
 RAMP_MAP_INV = {k: v for v, k in RAMP_MAP.items()}
 
 
-class lookup_table_ndarray(np.ndarray):
+class lookup_table_ndarray(np.ndarray):  # type: ignore[type-arg]
     """An ndarray which references the owning table and the underlying vtkArray.
 
     This class is used to ensure that the internal vtkLookupTable updates when
@@ -192,7 +202,7 @@ class LookupTable(_vtk.vtkLookupTable):
     _nan_color_set = False
     _cmap = None
     _values_manual = False
-    _opacity_parm: Tuple[Any, bool, str] = (None, False, 'quadratic')
+    _opacity_parm: tuple[Any, bool, str] = (None, False, 'quadratic')
 
     def __init__(
         self,
@@ -244,7 +254,7 @@ class LookupTable(_vtk.vtkLookupTable):
             self.annotations = annotations
 
     @property
-    def value_range(self) -> Optional[tuple]:  # numpydoc ignore=RT01
+    def value_range(self) -> tuple[float, float] | None:  # numpydoc ignore=RT01
         """Return or set the brightness of the mapped lookup table.
 
         This range is only used when creating custom color maps and will return
@@ -272,16 +282,16 @@ class LookupTable(_vtk.vtkLookupTable):
 
         """
         if self._cmap:
-            return
+            return None
         return self.GetValueRange()
 
     @value_range.setter
-    def value_range(self, value: tuple):  # numpydoc ignore=GL08
+    def value_range(self, value: tuple[float, float]):  # numpydoc ignore=GL08
         self.SetValueRange(value)
         self.rebuild()
 
     @property
-    def hue_range(self) -> Optional[tuple]:  # numpydoc ignore=RT01
+    def hue_range(self) -> tuple[float, float] | None:  # numpydoc ignore=RT01
         """Return or set the hue range.
 
         This range is only used when creating custom color maps and will return
@@ -309,16 +319,16 @@ class LookupTable(_vtk.vtkLookupTable):
 
         """
         if self._cmap:
-            return
+            return None
         return self.GetHueRange()
 
     @hue_range.setter
-    def hue_range(self, value: tuple):  # numpydoc ignore=GL08
+    def hue_range(self, value: tuple[float, float]):  # numpydoc ignore=GL08
         self.SetHueRange(value)
         self.rebuild()
 
     @property
-    def cmap(self) -> Optional[str]:  # numpydoc ignore=RT01
+    def cmap(self) -> str | None:  # numpydoc ignore=RT01
         """Return or set the color map used by this lookup table.
 
         Examples
@@ -389,7 +399,7 @@ class LookupTable(_vtk.vtkLookupTable):
         return '\n'.join(lines)
 
     @property
-    def scalar_range(self) -> tuple:  # numpydoc ignore=RT01
+    def scalar_range(self) -> tuple[float, float]:  # numpydoc ignore=RT01
         """Return or set the table range.
 
         This is the range of scalars which will be mapped to colors. Values
@@ -409,11 +419,11 @@ class LookupTable(_vtk.vtkLookupTable):
         return self.GetTableRange()
 
     @scalar_range.setter
-    def scalar_range(self, value: tuple):  # numpydoc ignore=GL08
+    def scalar_range(self, value: tuple[float, float]):  # numpydoc ignore=GL08
         self.SetTableRange(value)
 
     @property
-    def alpha_range(self) -> tuple:  # numpydoc ignore=RT01
+    def alpha_range(self) -> tuple[float, float] | None:  # numpydoc ignore=RT01
         """Return or set the alpha range.
 
         This range is only used when creating custom color maps and will return
@@ -438,12 +448,12 @@ class LookupTable(_vtk.vtkLookupTable):
         return self.GetAlphaRange()
 
     @alpha_range.setter
-    def alpha_range(self, value: tuple):  # numpydoc ignore=GL08
+    def alpha_range(self, value: tuple[float, float]):  # numpydoc ignore=GL08
         self.SetAlphaRange(value)
         self.rebuild()
 
     @property
-    def saturation_range(self) -> tuple:  # numpydoc ignore=RT01
+    def saturation_range(self) -> tuple[float, float] | None:  # numpydoc ignore=RT01
         """Return or set the saturation range.
 
         This range is only used when creating custom color maps and will return
@@ -468,7 +478,7 @@ class LookupTable(_vtk.vtkLookupTable):
         return self.GetSaturationRange()
 
     @saturation_range.setter
-    def saturation_range(self, value: tuple):  # numpydoc ignore=GL08
+    def saturation_range(self, value: tuple[float, float]):  # numpydoc ignore=GL08
         self.SetSaturationRange(value)
         self.rebuild()
 
@@ -489,7 +499,7 @@ class LookupTable(_vtk.vtkLookupTable):
         self.ForceBuild()
 
     @property
-    def nan_color(self) -> Optional[Color]:  # numpydoc ignore=RT01
+    def nan_color(self) -> Color | None:  # numpydoc ignore=RT01
         """Return or set the not a number (NAN) color.
 
         Any values that are NANs will be rendered with this color.
@@ -535,7 +545,7 @@ class LookupTable(_vtk.vtkLookupTable):
     @nan_opacity.setter
     def nan_opacity(self, value):  # numpydoc ignore=GL08
         # Hacky check to prevent auto activation
-        if not self._nan_color_set and (value == 1.0 or value == 255):
+        if not self._nan_color_set and (value in (1.0, 255)):
             return
         color = self.nan_color
         if color is None:
@@ -600,7 +610,7 @@ class LookupTable(_vtk.vtkLookupTable):
         self.rebuild()
 
     @property
-    def above_range_color(self) -> Optional[Color]:  # numpydoc ignore=RT01
+    def above_range_color(self) -> Color | None:  # numpydoc ignore=RT01
         """Return or set the above range color.
 
         Any values above :attr:`LookupTable.scalar_range` will be rendered with this
@@ -628,7 +638,7 @@ class LookupTable(_vtk.vtkLookupTable):
         return None
 
     @above_range_color.setter
-    def above_range_color(self, value: Union[bool, ColorLike]):  # numpydoc ignore=GL08
+    def above_range_color(self, value: bool | ColorLike):  # numpydoc ignore=GL08
         if value in (None, False):
             self.SetUseAboveRangeColor(False)
         elif value is True:
@@ -664,7 +674,7 @@ class LookupTable(_vtk.vtkLookupTable):
         self.above_range_color = Color(color, opacity=value)
 
     @property
-    def below_range_color(self) -> Optional[Color]:  # numpydoc ignore=RT01
+    def below_range_color(self) -> Color | None:  # numpydoc ignore=RT01
         """Return or set the below range color.
 
         Any values below :attr:`LookupTable.scalar_range` will be rendered with this
@@ -692,7 +702,7 @@ class LookupTable(_vtk.vtkLookupTable):
         return None
 
     @below_range_color.setter
-    def below_range_color(self, value: Union[bool, ColorLike]):  # numpydoc ignore=GL08
+    def below_range_color(self, value: bool | ColorLike):  # numpydoc ignore=GL08
         if value in (None, False):
             self.SetUseBelowRangeColor(False)
         elif value is True:
@@ -829,7 +839,10 @@ class LookupTable(_vtk.vtkLookupTable):
             self.values[:, -1] = np.array(opacity)
         else:
             self.values[:, -1] = opacity_transfer_function(
-                opacity, self.n_values, interpolate=interpolate, kind=kind
+                opacity,
+                self.n_values,
+                interpolate=interpolate,
+                kind=kind,
             )
         self._opacity_parm = (opacity, interpolate, kind)
 
@@ -899,14 +912,14 @@ class LookupTable(_vtk.vtkLookupTable):
             self.SetNumberOfTableValues(value)
         elif self._values_manual:
             raise RuntimeError(
-                'Number of values cannot be set when the values array has been manually set. Reassign the values array if you wish to change the number of values.'
+                'Number of values cannot be set when the values array has been manually set. Reassign the values array if you wish to change the number of values.',
             )
         else:
             self.SetNumberOfColors(value)
             self.ForceBuild()
 
     @property
-    def annotations(self) -> dict:  # numpydoc ignore=RT01
+    def annotations(self) -> dict[float, str]:  # numpydoc ignore=RT01
         """Return or set annotations.
 
         Pass a dictionary of annotations. Keys are the float values in the
@@ -934,7 +947,7 @@ class LookupTable(_vtk.vtkLookupTable):
         return dict(zip(keys, values))
 
     @annotations.setter
-    def annotations(self, values: Optional[dict]):  # numpydoc ignore=GL08
+    def annotations(self, values: dict[float, str] | None):  # numpydoc ignore=GL08
         self.ResetAnnotations()
         if values is not None:
             for val, anno in values.items():
@@ -945,7 +958,7 @@ class LookupTable(_vtk.vtkLookupTable):
         """Return the lookup type."""
         if self.cmap:
             if hasattr(self.cmap, 'name'):
-                return f'{self.cmap.name}'  # type: ignore
+                return f'{self.cmap.name}'
             else:  # pragma: no cover
                 return f'{self.cmap}'
         elif self._values_manual:
@@ -1039,9 +1052,16 @@ class LookupTable(_vtk.vtkLookupTable):
             color_tf.AddRGBPoint(ii, *self.map_value(value, False))
         return color_tf
 
-    def to_opacity_tf(self):
+    def to_opacity_tf(self, clamping: bool = True) -> _vtk.vtkPiecewiseFunction:
         """Return the opacity transfer function of this table.
 
+        Parameters
+        ----------
+        clamping : bool, optional
+            When zero range clamping is False, values returns 0.0 when a value is requested outside of the points specified.
+
+            .. versionadded:: 0.44
+
         Returns
         -------
         vtk.vtkPiecewiseFunction
@@ -1057,11 +1077,16 @@ class LookupTable(_vtk.vtkLookupTable):
 
         """
         opacity_tf = _vtk.vtkPiecewiseFunction()
+        opacity_tf.SetClamping(clamping)
         for ii, value in enumerate(self.values[:, 3]):
             opacity_tf.AddPoint(ii, value / self.n_values)
         return opacity_tf
 
-    def map_value(self, value: float, opacity: bool = True) -> tuple:
+    def map_value(
+        self,
+        value: float,
+        opacity: bool = True,
+    ) -> tuple[float, float, float] | tuple[float, float, float, float]:
         """Map a single value through the lookup table, returning an RBG(A) color.
 
         Parameters
@@ -1090,7 +1115,10 @@ class LookupTable(_vtk.vtkLookupTable):
         self.GetColor(value, color)
         if opacity:
             color.append(self.GetOpacity(value))
-        return tuple(color)
+        return cast(
+            Union[Tuple[float, float, float], Tuple[float, float, float, float]],
+            tuple(color),
+        )
 
     def __call__(self, value):
         """Implement a Matplotlib colormap-like call."""
