@@ -1,26 +1,33 @@
 """An internal module for wrapping the use of mappers."""
+
+from __future__ import annotations
+
 import sys
-from typing import Optional, Union, cast
+from typing import TYPE_CHECKING
+from typing import Optional
+from typing import cast
 
 import numpy as np
 
 import pyvista
-from pyvista.core._typing_core import BoundsLike
-from pyvista.core.utilities.arrays import (
-    FieldAssociation,
-    convert_array,
-    convert_string_array,
-    raise_not_matching,
-)
+from pyvista.core.utilities.arrays import FieldAssociation
+from pyvista.core.utilities.arrays import convert_array
+from pyvista.core.utilities.arrays import convert_string_array
+from pyvista.core.utilities.arrays import raise_not_matching
 from pyvista.core.utilities.helpers import wrap
-from pyvista.core.utilities.misc import abstract_class, no_new_attr
+from pyvista.core.utilities.misc import abstract_class
+from pyvista.core.utilities.misc import no_new_attr
 
 from . import _vtk
-from .colors import Color, get_cmap_safe
+from .colors import Color
+from .colors import get_cmap_safe
 from .lookup_table import LookupTable
 from .tools import normalize
 from .utilities.algorithms import set_algorithm_input
 
+if TYPE_CHECKING:  # pragma: no cover
+    from pyvista.core._typing_core import BoundsLike
+
 
 @abstract_class
 class _BaseMapper(_vtk.vtkAbstractMapper):
@@ -39,7 +46,8 @@ class _BaseMapper(_vtk.vtkAbstractMapper):
         self.lookup_table = LookupTable()
 
         self.interpolate_before_map = kwargs.get(
-            'interpolate_before_map', self._theme.interpolate_before_map
+            'interpolate_before_map',
+            self._theme.interpolate_before_map,
         )
 
     @property
@@ -56,7 +64,7 @@ class _BaseMapper(_vtk.vtkAbstractMapper):
         """
         return self.GetBounds()
 
-    def copy(self) -> '_BaseMapper':
+    def copy(self) -> _BaseMapper:
         """Create a copy of this mapper.
 
         Returns
@@ -80,7 +88,7 @@ class _BaseMapper(_vtk.vtkAbstractMapper):
         return new_mapper
 
     @property
-    def scalar_range(self) -> tuple:  # numpydoc ignore=RT01
+    def scalar_range(self) -> tuple[float, float]:  # numpydoc ignore=RT01
         """Return or set the scalar range.
 
         Examples
@@ -116,7 +124,7 @@ class _BaseMapper(_vtk.vtkAbstractMapper):
         self.SetScalarRange(*clim)
 
     @property
-    def lookup_table(self) -> 'pyvista.LookupTable':  # numpydoc ignore=RT01
+    def lookup_table(self) -> pyvista.LookupTable:  # numpydoc ignore=RT01
         """Return or set the lookup table.
 
         Examples
@@ -294,10 +302,10 @@ class _BaseMapper(_vtk.vtkAbstractMapper):
         return vtk_to_pv[self.GetScalarModeAsString()]
 
     @scalar_map_mode.setter
-    def scalar_map_mode(self, scalar_mode: Union[str, FieldAssociation]):  # numpydoc ignore=GL08
+    def scalar_map_mode(self, scalar_mode: str | FieldAssociation):  # numpydoc ignore=GL08
         if isinstance(scalar_mode, FieldAssociation):
             scalar_mode = scalar_mode.name
-        scalar_mode = scalar_mode.lower()  # type: ignore
+        scalar_mode = scalar_mode.lower()
         if scalar_mode == 'default':
             self.SetScalarModeToDefault()
         elif scalar_mode == 'point':
@@ -313,7 +321,7 @@ class _BaseMapper(_vtk.vtkAbstractMapper):
         else:
             raise ValueError(
                 f'Invalid `scalar_map_mode` "{scalar_mode}". Should be either '
-                '"default", "point", "cell", "point_field", "cell_field" or "field".'
+                '"default", "point", "cell", "point_field", "cell_field" or "field".',
             )
 
     @property
@@ -351,7 +359,7 @@ class _BaseMapper(_vtk.vtkAbstractMapper):
 
     @scalar_visibility.setter
     def scalar_visibility(self, value: bool):  # numpydoc ignore=GL08
-        return self.SetScalarVisibility(value)
+        self.SetScalarVisibility(value)
 
     def update(self):
         """Update this mapper."""
@@ -359,8 +367,8 @@ class _BaseMapper(_vtk.vtkAbstractMapper):
 
 
 @no_new_attr
-class DataSetMapper(_vtk.vtkDataSetMapper, _BaseMapper):
-    """Wrap _vtk.vtkDataSetMapper.
+class _DataSetMapper(_BaseMapper):
+    """Base wrapper for _vtk.vtkDataSetMapper.
 
     Parameters
     ----------
@@ -370,25 +378,14 @@ class DataSetMapper(_vtk.vtkDataSetMapper, _BaseMapper):
     theme : pyvista.plotting.themes.Theme, optional
         Plot-specific theme.
 
-    Examples
-    --------
-    Create a mapper outside :class:`pyvista.Plotter` and assign it to an
-    actor.
-
-    >>> import pyvista as pv
-    >>> mesh = pv.Cube()
-    >>> mapper = pv.DataSetMapper(dataset=mesh)
-    >>> actor = pv.Actor(mapper=mapper)
-    >>> actor.plot()
-
     """
 
     _cmap = None
 
     def __init__(
         self,
-        dataset: Optional['pyvista.DataSet'] = None,
-        theme: Optional['pyvista.themes.Theme'] = None,
+        dataset: pyvista.DataSet | None = None,
+        theme: pyvista.themes.Theme | None = None,
     ):
         """Initialize this class."""
         super().__init__(theme=theme)
@@ -396,13 +393,14 @@ class DataSetMapper(_vtk.vtkDataSetMapper, _BaseMapper):
             self.dataset = dataset
 
     @property
-    def dataset(self) -> Optional['pyvista.core.dataset.DataSet']:  # numpydoc ignore=RT01
+    def dataset(self) -> pyvista.core.dataset.DataSet | None:  # numpydoc ignore=RT01
         """Return or set the dataset assigned to this mapper."""
         return cast(Optional[pyvista.DataSet], wrap(self.GetInputAsDataSet()))
 
     @dataset.setter
     def dataset(
-        self, obj: Union['pyvista.core.dataset.DataSet', _vtk.vtkAlgorithm, _vtk.vtkAlgorithmOutput]
+        self,
+        obj: pyvista.core.dataset.DataSet | _vtk.vtkAlgorithm | _vtk.vtkAlgorithmOutput,
     ):  # numpydoc ignore=GL08
         set_algorithm_input(self, obj)
 
@@ -615,7 +613,8 @@ class DataSetMapper(_vtk.vtkDataSetMapper, _BaseMapper):
             scalars_name = '__custom_rgba'
 
         if not np.issubdtype(scalars.dtype, np.number) and not isinstance(
-            cmap, pyvista.LookupTable
+            cmap,
+            pyvista.LookupTable,
         ):
             # we can rapidly handle bools
             if scalars.dtype == np.bool_:
@@ -657,13 +656,13 @@ class DataSetMapper(_vtk.vtkDataSetMapper, _BaseMapper):
                 else:
                     raise ValueError(
                         'Component must be nonnegative and less than the '
-                        f'dimensionality of the scalars array: {scalars.shape[1]}'
+                        f'dimensionality of the scalars array: {scalars.shape[1]}',
                     )
             else:
                 scalars = scalars.ravel()
 
         if scalars.dtype == np.bool_:
-            scalars = scalars.astype(np.float_)
+            scalars = scalars.astype(np.float64)
 
         # Set scalars range
         if clim is None:
@@ -685,10 +684,7 @@ class DataSetMapper(_vtk.vtkDataSetMapper, _BaseMapper):
             self.lookup_table.scalar_range = self.scalar_range
             # Set default map
             if cmap is None:
-                if self._theme is None:
-                    cmap = pyvista.global_theme.cmap
-                else:
-                    cmap = self._theme.cmap
+                cmap = pyvista.global_theme.cmap if self._theme is None else self._theme.cmap
 
             # have to add the attribute to pass it onward to some classes
             if isinstance(cmap, str):
@@ -741,10 +737,71 @@ class DataSetMapper(_vtk.vtkDataSetMapper, _BaseMapper):
             self.as_rgba()
 
     @property
-    def cmap(self) -> Optional[str]:  # numpydoc ignore=RT01
+    def cmap(self) -> str | None:  # numpydoc ignore=RT01
         """Colormap assigned to this mapper."""
         return self._cmap
 
+    @property
+    def resolve(self) -> str:
+        """Set or return the global flag to avoid z-buffer resolution.
+
+        A global flag that controls whether the coincident topology
+        (e.g., a line on top of a polygon) is shifted to avoid
+        z-buffer resolution (and hence rendering problems).
+
+        If not off, there are two methods to choose from.
+        `polygon_offset` uses graphics systems calls to shift polygons,
+        lines, and points from each other.
+        `shift_zbuffer` is a legacy method that is used to remap the z-buffer
+        to distinguish vertices, lines, and polygons,
+        but does not always produce acceptable results.
+        You should only use the polygon_offset method (or none) at this point.
+
+        Returns
+        -------
+        str
+            Global flag to avoid z-buffer resolution.
+            Must be either `off`, `polygon_offset` or `shift_zbuffer`.
+
+        Examples
+        --------
+        >>> import pyvista as pv
+        >>> from pyvista import examples
+
+        >>> mesh = examples.download_tri_quadratic_hexahedron()
+        >>> surface_sep = mesh.separate_cells().extract_surface(
+        ...     nonlinear_subdivision=4
+        ... )
+        >>> edges = surface_sep.extract_feature_edges()
+        >>> surface = mesh.extract_surface(nonlinear_subdivision=4)
+
+        >>> plotter = pv.Plotter()
+        >>> _ = plotter.add_mesh(
+        ...     surface, smooth_shading=True, split_sharp_edges=True
+        ... )
+        >>> actor = plotter.add_mesh(edges, color='k', line_width=3)
+        >>> actor.mapper.resolve = "polygon_offset"
+        >>> plotter.show()
+
+        """
+        vtk_to_pv = {
+            _vtk.VTK_RESOLVE_OFF: 'off',
+            _vtk.VTK_RESOLVE_POLYGON_OFFSET: 'polygon_offset',
+            _vtk.VTK_RESOLVE_SHIFT_ZBUFFER: 'shift_zbuffer',
+        }
+        return vtk_to_pv[self.GetResolveCoincidentTopology()]
+
+    @resolve.setter
+    def resolve(self, resolve):  # numpydoc ignore=GL08
+        if resolve == 'off':
+            self.SetResolveCoincidentTopologyToOff()
+        elif resolve == 'polygon_offset':
+            self.SetResolveCoincidentTopologyToPolygonOffset()
+        elif resolve == 'shift_zbuffer':
+            self.SetResolveCoincidentTopologyToShiftZBuffer()
+        else:
+            raise ValueError('Resolve must be either "off", "polygon_offset" or "shift_zbuffer"')
+
     def set_custom_opacity(self, opacity, color, n_colors, preference='point'):
         """Set custom opacity.
 
@@ -774,13 +831,10 @@ class DataSetMapper(_vtk.vtkDataSetMapper, _BaseMapper):
             raise ValueError(
                 f"Opacity array size ({opacity.size}) does not equal "
                 f"the number of points ({self.dataset.n_points}) or the "
-                f"number of cells ({self.dataset.n_cells})."
+                f"number of cells ({self.dataset.n_cells}).",
             )
 
-        if self._theme is not None:
-            default_color = self._theme.color
-        else:
-            default_color = pyvista.global_theme.color
+        default_color = self._theme.color if self._theme is not None else pyvista.global_theme.color
 
         rgba[:, :-1] = Color(color, default_color=default_color).int_rgb
         rgba[:, -1] = np.around(opacity * 255)
@@ -807,8 +861,41 @@ class DataSetMapper(_vtk.vtkDataSetMapper, _BaseMapper):
         return '\n'.join(mapper_attr)
 
 
+class DataSetMapper(_DataSetMapper, _vtk.vtkDataSetMapper):
+    """Wrap _vtk.vtkDataSetMapper.
+
+    Parameters
+    ----------
+    dataset : pyvista.DataSet, optional
+        Dataset to assign to this mapper.
+
+    theme : pyvista.plotting.themes.Theme, optional
+        Plot-specific theme.
+
+    Examples
+    --------
+    Create a mapper outside :class:`pyvista.Plotter` and assign it to an
+    actor.
+
+    >>> import pyvista as pv
+    >>> mesh = pv.Cube()
+    >>> mapper = pv.DataSetMapper(dataset=mesh)
+    >>> actor = pv.Actor(mapper=mapper)
+    >>> actor.plot()
+
+    """
+
+    def __init__(
+        self,
+        dataset: pyvista.DataSet | None = None,
+        theme: pyvista.themes.Theme | None = None,
+    ):
+        """Initialize this class."""
+        super().__init__(dataset=dataset, theme=theme)
+
+
 @no_new_attr
-class PointGaussianMapper(_vtk.vtkPointGaussianMapper, DataSetMapper):
+class PointGaussianMapper(_DataSetMapper, _vtk.vtkPointGaussianMapper):
     """Wrap vtkPointGaussianMapper.
 
     Parameters
@@ -841,7 +928,7 @@ class PointGaussianMapper(_vtk.vtkPointGaussianMapper, DataSetMapper):
 
     @emissive.setter
     def emissive(self, value: bool):  # numpydoc ignore=GL08
-        return self.SetEmissive(value)
+        self.SetEmissive(value)
 
     @property
     def scale_factor(self) -> float:  # numpydoc ignore=RT01
@@ -855,7 +942,56 @@ class PointGaussianMapper(_vtk.vtkPointGaussianMapper, DataSetMapper):
 
     @scale_factor.setter
     def scale_factor(self, value: float):  # numpydoc ignore=GL08
-        return self.SetScaleFactor(value)
+        self.SetScaleFactor(value)
+
+    @property
+    def scale_array(self) -> str:  # numpydoc ignore=RT01
+        """Set or return the name of the array used to scale the splats.
+
+        Scalars used to scale the gaussian points. Accepts a string
+        name of an array that is present on the mesh.
+
+        Notes
+        -----
+        Setting this automatically sets ``scale_factor = 1.0``.
+
+        Examples
+        --------
+        Plot spheres using `style='points_gaussian'` style and scale them by
+        radius.
+
+        >>> import numpy as np
+        >>> import pyvista as pv
+        >>> n_spheres = 1_000
+        >>> pos = np.random.random((n_spheres, 3))
+        >>> rad = np.random.random(n_spheres) * 0.01
+        >>> pdata = pv.PolyData(pos)
+        >>> pdata['radius'] = rad
+        >>> pl = pv.Plotter()
+        >>> actor = pl.add_mesh(
+        ...     pdata,
+        ...     style='points_gaussian',
+        ...     emissive=False,
+        ...     render_points_as_spheres=True,
+        ... )
+        >>> actor.mapper.scale_array = 'radius'
+        >>> pl.show()
+        """
+        return self.GetScaleArray()
+
+    @scale_array.setter
+    def scale_array(self, name: str):  # numpydoc ignore=GL08
+        if not self.dataset:  # pragma: no cover
+            raise RuntimeError('Missing dataset.')
+        if name not in self.dataset.point_data:
+            available_arrays = ", ".join(self.dataset.point_data.keys())
+            raise KeyError(
+                f'Point array "{name}" does not exist. '
+                f'Available point arrays are: {available_arrays}',
+            )
+
+        self.scale_factor = 1.0
+        self.SetScaleArray(name)
 
     def use_circular_splat(self, opacity: float = 1.0):
         """Set the fragment shader code to create a circular splat.
@@ -879,10 +1015,9 @@ class PointGaussianMapper(_vtk.vtkPointGaussianMapper, DataSetMapper):
             f"  float scale = ({opacity} - dist);\n"
             "  ambientColor *= scale;\n"
             "  diffuseColor *= scale;\n"
-            "}\n"
+            "}\n",
         )
         # maintain consistency with the default style
-        self.emissive = True
         self.scale_factor *= 1.5
 
     def use_default_splat(self):
@@ -921,7 +1056,7 @@ class _BaseVolumeMapper(_BaseMapper):
     @property
     def interpolate_before_map(self):  # numpydoc ignore=RT01
         """Interpolate before map is not supported with volume mappers."""
-        return None
+        return
 
     @interpolate_before_map.setter
     def interpolate_before_map(self, *args):  # numpydoc ignore=GL08
@@ -935,7 +1070,8 @@ class _BaseVolumeMapper(_BaseMapper):
 
     @dataset.setter
     def dataset(
-        self, obj: Union['pyvista.core.dataset.DataSet', _vtk.vtkAlgorithm, _vtk.vtkAlgorithmOutput]
+        self,
+        obj: pyvista.core.dataset.DataSet | _vtk.vtkAlgorithm | _vtk.vtkAlgorithmOutput,
     ):
         set_algorithm_input(self, obj)
 
@@ -948,7 +1084,7 @@ class _BaseVolumeMapper(_BaseMapper):
         self._lut = lut
 
     @property
-    def scalar_range(self) -> tuple:  # numpydoc ignore=RT01
+    def scalar_range(self) -> tuple[float, float]:  # numpydoc ignore=RT01
         """Return or set the scalar range."""
         return self._scalar_range
 
@@ -976,23 +1112,13 @@ class _BaseVolumeMapper(_BaseMapper):
 
         """
         value = self.GetBlendMode()
-        if value == 0:
-            return 'composite'
-        elif value == 1:
-            return 'maximum'
-        elif value == 2:
-            return 'minimum'
-        elif value == 3:
-            return 'average'
-        elif value == 4:
-            return 'additive'
-
-        raise NotImplementedError(
-            f'Unsupported blend mode return value {value}'
-        )  # pragma: no cover
+        mode = {0: 'composite', 1: 'maximum', 2: 'minimum', 3: 'average', 4: 'additive'}.get(value)
+        if mode is None:  # pragma: no cover
+            raise NotImplementedError(f'Unsupported blend mode return value {value}')
+        return mode
 
     @blend_mode.setter
-    def blend_mode(self, value: Union[str, int]):  # numpydoc ignore=GL08
+    def blend_mode(self, value: str | int):  # numpydoc ignore=GL08
         if isinstance(value, int):
             self.SetBlendMode(value)
         elif isinstance(value, str):
@@ -1011,7 +1137,7 @@ class _BaseVolumeMapper(_BaseMapper):
                 raise ValueError(
                     f'Blending mode {value!r} invalid. '
                     'Please choose either "additive", '
-                    '"composite", "minimum" or "maximum".'
+                    '"composite", "minimum" or "maximum".',
                 )
         else:
             raise TypeError(f'`blend_mode` should be either an int or str, not `{type(value)}`')
@@ -1020,33 +1146,23 @@ class _BaseVolumeMapper(_BaseMapper):
         self._lut = None
 
 
-class FixedPointVolumeRayCastMapper(_vtk.vtkFixedPointVolumeRayCastMapper, _BaseVolumeMapper):
+class FixedPointVolumeRayCastMapper(_BaseVolumeMapper, _vtk.vtkFixedPointVolumeRayCastMapper):
     """Wrap _vtk.vtkFixedPointVolumeRayCastMapper."""
 
-    pass
 
-
-class GPUVolumeRayCastMapper(_vtk.vtkGPUVolumeRayCastMapper, _BaseVolumeMapper):
+class GPUVolumeRayCastMapper(_BaseVolumeMapper, _vtk.vtkGPUVolumeRayCastMapper):
     """Wrap _vtk.vtkGPUVolumeRayCastMapper."""
 
-    pass
 
-
-class OpenGLGPUVolumeRayCastMapper(_vtk.vtkOpenGLGPUVolumeRayCastMapper, _BaseVolumeMapper):
+class OpenGLGPUVolumeRayCastMapper(_BaseVolumeMapper, _vtk.vtkOpenGLGPUVolumeRayCastMapper):
     """Wrap _vtk.vtkOpenGLGPUVolumeRayCastMapper."""
 
-    pass
 
-
-class SmartVolumeMapper(_vtk.vtkSmartVolumeMapper, _BaseVolumeMapper):
+class SmartVolumeMapper(_BaseVolumeMapper, _vtk.vtkSmartVolumeMapper):
     """Wrap _vtk.vtkSmartVolumeMapper."""
 
-    pass
-
 
 class UnstructuredGridVolumeRayCastMapper(
-    _vtk.vtkUnstructuredGridVolumeRayCastMapper, _BaseVolumeMapper
+    _BaseVolumeMapper, _vtk.vtkUnstructuredGridVolumeRayCastMapper
 ):
     """Wrap _vtk.vtkUnstructuredGridVolumeMapper."""
-
-    pass
