@@ -1,6 +1,9 @@
 """Organize Renderers for ``pyvista.Plotter``."""
-import collections
+
+from __future__ import annotations
+
 from itertools import product
+from typing import Sequence
 from weakref import proxy
 
 import numpy as np
@@ -64,10 +67,7 @@ class Renderers:
 
         # by default add border for multiple plots
         if border is None:
-            if shape != (1, 1):
-                border = True
-            else:
-                border = False
+            border = shape != (1, 1)
 
         self.groups = np.empty((0, 4), dtype=int)
 
@@ -87,41 +87,38 @@ class Renderers:
                 splitting_position = pyvista.global_theme.multi_rendering_splitting_position
 
             if splitting_position is None:
-                if n >= m:
-                    xsplit = m / (n + m)
-                else:
-                    xsplit = 1 - n / (n + m)
+                xsplit = m / (n + m) if n >= m else 1 - n / (n + m)
             else:
                 xsplit = splitting_position
 
             for i in rangen:
                 arenderer = Renderer(self._plotter, border, border_color, border_width)
                 if '|' in shape:
-                    arenderer.SetViewport(0, i / n, xsplit, (i + 1) / n)
+                    arenderer.viewport = (0, i / n, xsplit, (i + 1) / n)
                 else:
-                    arenderer.SetViewport(i / n, 0, (i + 1) / n, xsplit)
+                    arenderer.viewport = (i / n, 0, (i + 1) / n, xsplit)
                 self._renderers.append(arenderer)
             for i in rangem:
                 arenderer = Renderer(self._plotter, border, border_color, border_width)
                 if '|' in shape:
-                    arenderer.SetViewport(xsplit, i / m, 1, (i + 1) / m)
+                    arenderer.viewport = (xsplit, i / m, 1, (i + 1) / m)
                 else:
-                    arenderer.SetViewport(i / m, xsplit, (i + 1) / m, 1)
+                    arenderer.viewport = (i / m, xsplit, (i + 1) / m, 1)
                 self._renderers.append(arenderer)
 
             self._shape = (n + m,)
             self._render_idxs = np.arange(n + m)
 
         else:
-            if not isinstance(shape, (np.ndarray, collections.abc.Sequence)):
+            if not isinstance(shape, (np.ndarray, Sequence)):
                 raise TypeError('"shape" should be a list, tuple or string descriptor')
             if len(shape) != 2:
                 raise ValueError('"shape" must have length 2.')
             shape = np.asarray(shape)
             if not np.issubdtype(shape.dtype, np.integer) or (shape <= 0).any():
                 raise ValueError('"shape" must contain only positive integers.')
-            # always assign shape as a tuple
-            self._shape = tuple(shape)
+            # always assign shape as a tuple of native ints
+            self._shape = tuple(size.item() for size in shape)
             self._render_idxs = np.empty(self._shape, dtype=int)
             # Check if row and col weights correspond to given shape,
             # or initialize them to defaults (equally weighted).
@@ -139,13 +136,13 @@ class Renderers:
                 raise ValueError(
                     f'"row_weights" must have {shape[0]} items '
                     f'for {shape[0]} rows of subplots, not '
-                    f'{row_weights.size}.'
+                    f'{row_weights.size}.',
                 )
             if col_weights.size != shape[1]:
                 raise ValueError(
                     f'"col_weights" must have {shape[1]} items '
                     f'for {shape[1]} columns of subplots, not '
-                    f'{col_weights.size}.'
+                    f'{col_weights.size}.',
                 )
             row_off = np.cumsum(row_weights) / np.sum(row_weights)
             row_off = 1 - np.concatenate(([0], row_off))
@@ -157,15 +154,15 @@ class Renderers:
             # top left cell)
 
             if groups is not None:
-                if not isinstance(groups, collections.abc.Sequence):
+                if not isinstance(groups, Sequence):
                     raise TypeError(
-                        f'"groups" should be a list or tuple, not {type(groups).__name__}.'
+                        f'"groups" should be a list or tuple, not {type(groups).__name__}.',
                     )
                 for group in groups:
-                    if not isinstance(group, collections.abc.Sequence):
+                    if not isinstance(group, Sequence):
                         raise TypeError(
                             'Each group entry should be a list or '
-                            f'tuple, not {type(group).__name__}.'
+                            f'tuple, not {type(group).__name__}.',
                         )
                     if len(group) != 2:
                         raise ValueError('Each group entry must have length 2.')
@@ -186,10 +183,11 @@ class Renderers:
                     ):
                         if self.loc_to_group((i, j)) is not None:
                             raise ValueError(
-                                f'Groups cannot overlap. Overlap found at position {(i, j)}.'
+                                f'Groups cannot overlap. Overlap found at position {(i, j)}.',
                             )
                     self.groups = np.concatenate(
-                        (self.groups, np.array([norm_group], dtype=int)), axis=0
+                        (self.groups, np.array([norm_group], dtype=int)),
+                        axis=0,
                     )
             # Create subplot renderers
             for row, col in product(range(shape[0]), range(shape[1])):
@@ -210,12 +208,13 @@ class Renderers:
                     y0 = row_off[row + nb_rows]
                     x1 = col_off[col + nb_cols]
                     y1 = row_off[row]
-                    renderer.SetViewport(x0, y0, x1, y1)
+                    renderer.viewport = (x0, y0, x1, y1)
                     self._render_idxs[row, col] = len(self)
                     self._renderers.append(renderer)
                 else:
                     self._render_idxs[row, col] = self._render_idxs[
-                        self.groups[group, 0], self.groups[group, 1]
+                        self.groups[group, 0],
+                        self.groups[group, 1],
                     ]
 
         # each render will also have an associated background renderer
@@ -223,7 +222,7 @@ class Renderers:
 
         # create a shadow renderer that lives on top of all others
         self._shadow_renderer = Renderer(self._plotter, border, border_color, border_width)
-        self._shadow_renderer.SetViewport(0, 0, 1, 1)
+        self._shadow_renderer.viewport = (0, 0, 1, 1)
         self._shadow_renderer.SetDraw(False)
 
     def loc_to_group(self, loc):
@@ -267,7 +266,7 @@ class Renderers:
         """
         if isinstance(loc, (int, np.integer)):
             return loc
-        elif isinstance(loc, (np.ndarray, collections.abc.Sequence)):
+        elif isinstance(loc, (np.ndarray, Sequence)):
             if not len(loc) == 2:
                 raise ValueError('"loc" must contain two items')
             index_row = loc[0]
@@ -313,13 +312,13 @@ class Renderers:
 
         Returns
         -------
-        numpy.ndarray
+        numpy.ndarray or numpy.int64
             2D location on the plotting grid.
         """
         if not isinstance(index, (int, np.integer)):
             raise TypeError('"index" must be a scalar integer.')
         if len(self.shape) == 1:
-            return index
+            return np.intp(index)
         args = np.argwhere(self._render_idxs == index)
         if len(args) < 1:
             raise IndexError(f'Index ({index}) is out of range.')
@@ -337,12 +336,12 @@ class Renderers:
         return self._renderers[self._active_index]
 
     @property
-    def shape(self):  # numpydoc ignore=RT01
+    def shape(self) -> tuple[int] | tuple[int, int]:
         """Return the shape of the renderers.
 
         Returns
         -------
-        tuple
+        tuple[int] | tuple[int, int]
             Shape of the renderers.
         """
         return self._shape
@@ -525,7 +524,13 @@ class Renderers:
         return self._shadow_renderer
 
     def set_background(
-        self, color, top=None, right=None, side=None, corner=None, all_renderers=True
+        self,
+        color,
+        top=None,
+        right=None,
+        side=None,
+        corner=None,
+        all_renderers=True,
     ):
         """Set the background color.
 
@@ -591,7 +596,11 @@ class Renderers:
             self._shadow_renderer.set_background(color)
         else:
             self.active_renderer.set_background(
-                color, top=top, right=right, side=side, corner=corner
+                color,
+                top=top,
+                right=right,
+                side=side,
+                corner=corner,
             )
 
     def set_color_cycler(self, color_cycler, all_renderers=True):
