@@ -1,19 +1,29 @@
 """Contains the pyvista.Text class."""
+
 from __future__ import annotations
 
-import os
 import pathlib
-from typing import Sequence
+from pathlib import Path
+from typing import TYPE_CHECKING
 
 import pyvista
-from pyvista.core.utilities.misc import _check_range, no_new_attr
+from pyvista.core import _validation
+from pyvista.core.utilities.misc import _check_range
+from pyvista.core.utilities.misc import no_new_attr
 
 from . import _vtk
-from ._typing import ColorLike
 from .colors import Color
 from .themes import Theme
 from .tools import FONTS
 
+if TYPE_CHECKING:  # pragma: no cover
+    from typing import ClassVar
+    from typing import Sequence
+
+    from pyvista.core._typing_core import VectorLike
+
+    from ._typing import ColorLike
+
 
 @no_new_attr
 class CornerAnnotation(_vtk.vtkCornerAnnotation):
@@ -220,6 +230,85 @@ class Text(_vtk.vtkTextActor):
         self.SetPosition(position[0], position[1])
 
 
+class Label(Text):
+    """2D label actor with a 3D position coordinate.
+
+    Parameters
+    ----------
+    text : str, optional
+        Text string to be displayed.
+
+    position : VectorLike[float]
+        The position coordinate.
+
+    size : int
+        Size of the text label.
+
+    prop : pyvista.TextProperty, optional
+        The property of this actor.
+
+    See Also
+    --------
+    pyvista.Plotter.add_point_labels
+
+    Examples
+    --------
+    Create a label for a point of interest.
+
+    >>> import pyvista as pv
+    >>> mesh = pv.Cone()
+    >>> tip_point = mesh.points[0]
+    >>> label = pv.Label('tip', position=tip_point)
+
+    Plot the mesh and label.
+
+    >>> pl = pv.Plotter()
+    >>> _ = pl.add_mesh(mesh)
+    >>> _ = pl.add_actor(label)
+    >>> pl.show()
+    """
+
+    _new_attr_exceptions: ClassVar[tuple[str]] = ('size',)
+
+    def __init__(
+        self,
+        text: str | None = None,
+        position: VectorLike[float] = (0.0, 0.0, 0.0),
+        *,
+        size: int = 50,
+        prop: pyvista.Property | None = None,
+    ):
+        super().__init__(text=text, prop=prop)
+        self.GetPositionCoordinate().SetCoordinateSystemToWorld()
+        self.SetTextScaleModeToNone()  # Use font size to control size of text
+        self.position = position  # type: ignore[assignment]
+        self.size = size
+
+    @property
+    def position(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
+        """Text position coordinate in xyz space."""
+        return self.GetPositionCoordinate().GetValue()
+
+    @position.setter
+    def position(self, position: VectorLike[float]):  # numpydoc ignore=GL08
+        valid_position = _validation.validate_array3(position)
+        self.GetPositionCoordinate().SetValue(valid_position)
+
+    @property
+    def size(self) -> int:  # numpydoc ignore=RT01
+        """Size of the text label.
+
+        Notes
+        -----
+        The text property's font size used to control the size of the label.
+        """
+        return self.prop.font_size
+
+    @size.setter
+    def size(self, size: int):  # numpydoc ignore=GL08
+        self.prop.font_size = size
+
+
 @no_new_attr
 class TextProperty(_vtk.vtkTextProperty):
     """Define text's property.
@@ -258,6 +347,18 @@ class TextProperty(_vtk.vtkTextProperty):
         Text's vertical justification.
         Should be either "bottom", "center" or "top".
 
+    italic : bool, default: False
+        Italicises title and bar labels.
+
+    bold : bool, default: True
+        Bolds title and bar labels.
+
+    background_color : pyvista.Color, optional
+        Background color of text.
+
+    background_opacity : pyvista.Color, optional
+        Background opacity of text.
+
     Examples
     --------
     Create a text's property.
@@ -291,6 +392,10 @@ class TextProperty(_vtk.vtkTextProperty):
         shadow=False,
         justification_horizontal=None,
         justification_vertical=None,
+        italic=False,
+        bold=False,
+        background_color=None,
+        background_opacity=None,
     ):
         """Initialize text's property."""
         super().__init__()
@@ -314,6 +419,12 @@ class TextProperty(_vtk.vtkTextProperty):
             self.justification_horizontal = justification_horizontal
         if justification_vertical is not None:
             self.justification_vertical = justification_vertical
+        self.italic = italic
+        self.bold = bold
+        if background_color is not None:
+            self.background_color = background_color
+        if background_opacity is not None:
+            self.background_opacity = background_opacity
 
     @property
     def color(self) -> Color:
@@ -496,7 +607,7 @@ class TextProperty(_vtk.vtkTextProperty):
         """
         path = pathlib.Path(font_file)
         path = path.resolve()
-        if not os.path.isfile(path):
+        if not Path(path).is_file():
             raise FileNotFoundError(f'Unable to locate {path}')
         self.SetFontFamily(_vtk.VTK_FONT_FILE)
         self.SetFontFile(str(path))
@@ -527,7 +638,7 @@ class TextProperty(_vtk.vtkTextProperty):
         else:
             raise ValueError(
                 f'Invalid {justification} for justification_horizontal. '
-                'Should be either "left", "center" or "right".'
+                'Should be either "left", "center" or "right".',
             )
 
     @property
@@ -556,5 +667,37 @@ class TextProperty(_vtk.vtkTextProperty):
         else:
             raise ValueError(
                 f'Invalid {justification} for justification_vertical. '
-                'Should be either "bottom", "center" or "top".'
+                'Should be either "bottom", "center" or "top".',
             )
+
+    @property
+    def italic(self) -> bool:
+        """Italic of text's property.
+
+        Returns
+        -------
+        bool
+            If text is italic.
+
+        """
+        return bool(self.GetItalic())
+
+    @italic.setter
+    def italic(self, italic: bool):  # numpydoc ignore=GL08
+        self.SetItalic(italic)
+
+    @property
+    def bold(self) -> bool:
+        """Bold of text's property.
+
+        Returns
+        -------
+        bool
+            If text is bold.
+
+        """
+        return bool(self.GetBold())
+
+    @bold.setter
+    def bold(self, bold: bool):  # numpydoc ignore=GL08
+        self.SetBold(bold)
