@@ -1,11 +1,21 @@
 """Tests for pyvista.core.dataset."""
 
+from __future__ import annotations
+
 import multiprocessing
 import pickle
+from typing import TYPE_CHECKING
 
-from hypothesis import HealthCheck, assume, given, settings
-from hypothesis.extra.numpy import array_shapes, arrays
-from hypothesis.strategies import composite, floats, integers, one_of
+from hypothesis import HealthCheck
+from hypothesis import assume
+from hypothesis import given
+from hypothesis import settings
+from hypothesis.extra.numpy import array_shapes
+from hypothesis.extra.numpy import arrays
+from hypothesis.strategies import composite
+from hypothesis.strategies import floats
+from hypothesis.strategies import integers
+from hypothesis.strategies import one_of
 import numpy as np
 import pytest
 import vtk
@@ -13,17 +23,18 @@ from vtk.util.numpy_support import vtk_to_numpy
 
 import pyvista as pv
 from pyvista import examples
-from pyvista.core.dataset import DataSet
-from pyvista.core.errors import PyVistaDeprecationWarning, VTKVersionError
-from pyvista.examples import (
-    load_airplane,
-    load_explicit_structured,
-    load_hexbeam,
-    load_rectilinear,
-    load_structured,
-    load_tetbeam,
-    load_uniform,
-)
+from pyvista.core.errors import PyVistaDeprecationWarning
+from pyvista.core.errors import VTKVersionError
+from pyvista.examples import load_airplane
+from pyvista.examples import load_explicit_structured
+from pyvista.examples import load_hexbeam
+from pyvista.examples import load_rectilinear
+from pyvista.examples import load_structured
+from pyvista.examples import load_tetbeam
+from pyvista.examples import load_uniform
+
+if TYPE_CHECKING:  # pragma: no cover
+    from pyvista.core.dataset import DataSet
 
 HYPOTHESIS_MAX_EXAMPLES = 20
 
@@ -81,7 +92,7 @@ def test_point_data_bad_value(grid):
     with pytest.raises(TypeError):
         grid.point_data['new_array'] = None
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.point_data['new_array'] = np.arange(grid.n_points - 1)
 
 
@@ -121,7 +132,7 @@ def test_cell_data_bad_value(grid):
     with pytest.raises(TypeError):
         grid.cell_data['new_array'] = None
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.cell_data['new_array'] = np.arange(grid.n_cells - 1)
 
 
@@ -162,11 +173,37 @@ def test_field_data(grid):
     assert isinstance(grid.field_data['foo'], np.ndarray)
     assert np.allclose(grid.field_data['foo'], foo)
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.set_active_scalars('foo')
 
 
-@pytest.mark.parametrize('field', (range(5), np.ones((3, 3))[:, 0]))
+def test_field_data_string(grid):
+    # test `mesh.field_data`
+    field_name = 'foo'
+    field_value = 'bar'
+    grid.field_data[field_name] = field_value
+    returned = grid.field_data[field_name]
+    assert returned == field_value
+    assert isinstance(returned, str)
+
+    # test `mesh.add_field_data`
+    field_name = 'eggs'
+    field_value = 'ham'
+    grid.add_field_data(array=field_value, name=field_name)
+    returned = grid.field_data[field_name]
+    assert returned == field_value
+    assert isinstance(returned, str)
+
+    # test `mesh[name] = data`
+    field_name = 'baz'
+    field_value = 'a' * grid.n_points
+    grid[field_name] = field_value
+    returned = grid.field_data[field_name]
+    assert returned == field_value
+    assert isinstance(returned, str)
+
+
+@pytest.mark.parametrize('field', [range(5), np.ones((3, 3))[:, 0]])
 def test_add_field_data(grid, field):
     grid.add_field_data(field, 'foo')
     assert isinstance(grid.field_data['foo'], np.ndarray)
@@ -281,19 +318,19 @@ def test_translate_should_fail_given_none(grid):
 
 def test_set_points():
     dataset = pv.UnstructuredGrid()
-    points = np.random.random((10, 3))
+    points = np.random.default_rng().random((10, 3))
     dataset.points = pv.vtk_points(points)
 
 
 def test_translate_should_fail_bad_points_or_transform(grid):
-    points = np.random.random((10, 2))
-    bad_points = np.random.random((10, 2))
-    trans = np.random.random((4, 4))
-    bad_trans = np.random.random((2, 4))
-    with pytest.raises(ValueError):
+    points = np.random.default_rng().random((10, 2))
+    bad_points = np.random.default_rng().random((10, 2))
+    trans = np.random.default_rng().random((4, 4))
+    bad_trans = np.random.default_rng().random((2, 4))
+    with pytest.raises(ValueError):  # noqa: PT011
         pv.core.utilities.transformations.apply_transformation_to_points(trans, bad_points)
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         pv.core.utilities.transformations.apply_transformation_to_points(bad_trans, points)
 
 
@@ -304,7 +341,7 @@ def test_translate_should_fail_bad_points_or_transform(grid):
 @given(array=arrays(dtype=np.float32, shape=array_shapes(max_dims=5, max_side=5)))
 def test_transform_should_fail_given_wrong_numpy_shape(array, grid):
     assume(array.shape != (4, 4))
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.transform(array)
 
 
@@ -322,7 +359,7 @@ def test_translate_should_translate_grid(grid, axis_amounts):
     max_examples=HYPOTHESIS_MAX_EXAMPLES,
 )
 @given(angle=one_of(floats(allow_infinity=False, allow_nan=False), integers()))
-@pytest.mark.parametrize('axis', ('x', 'y', 'z'))
+@pytest.mark.parametrize('axis', ['x', 'y', 'z'])
 def test_rotate_should_match_vtk_rotation(angle, axis, grid):
     trans = vtk.vtkTransform()
     getattr(trans, f'Rotate{axis.upper()}')(angle)
@@ -475,8 +512,8 @@ def test_html_repr(grid):
     assert grid._repr_html_() is not None
 
 
-@pytest.mark.parametrize('html', (True, False))
-@pytest.mark.parametrize('display', (True, False))
+@pytest.mark.parametrize('html', [True, False])
+@pytest.mark.parametrize('display', [True, False])
 def test_print_repr(grid, display, html):
     """
     This just tests to make sure no errors are thrown on the text friendly
@@ -490,13 +527,13 @@ def test_print_repr(grid, display, html):
 
 
 def test_invalid_vector(grid):
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid["vectors"] = np.empty(10)
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid["vectors"] = np.empty((3, 2))
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid["vectors"] = np.empty((3, 3))
 
 
@@ -513,7 +550,7 @@ def test_arrows():
 
     # make cool swirly pattern
     vectors = np.vstack(
-        (np.sin(sphere.points[:, 0]), np.cos(sphere.points[:, 1]), np.cos(sphere.points[:, 2]))
+        (np.sin(sphere.points[:, 0]), np.cos(sphere.points[:, 1]), np.cos(sphere.points[:, 2])),
     ).T
 
     # add and scales
@@ -541,7 +578,8 @@ def active_component_consistency_check(grid, component_type, field_association="
 
     pv_arr = getattr(grid, "active_" + component_type)
     vtk_arr = getattr(
-        getattr(grid, f"Get{vtk_field_association}Data")(), f"Get{vtk_component_type}"
+        getattr(grid, f"Get{vtk_field_association}Data")(),
+        f"Get{vtk_component_type}",
     )()
 
     assert (pv_arr is None and vtk_arr is None) or np.allclose(pv_arr, vtk_to_numpy(vtk_arr))
@@ -577,18 +615,18 @@ def test_set_texture_coordinates(grid):
     with pytest.raises(TypeError):
         grid.active_texture_coordinates = [1, 2, 3]
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.active_texture_coordinates = np.empty(10)
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.active_texture_coordinates = np.empty((3, 3))
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.active_texture_coordinates = np.empty((grid.n_points, 1))
 
 
 def test_set_active_vectors_fail(grid):
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.set_active_vectors('not a vector')
 
     active_component_consistency_check(grid, "vectors", "point")
@@ -599,7 +637,7 @@ def test_set_active_vectors_fail(grid):
 
     grid.point_data['scalar_arr'] = np.zeros([grid.n_points])
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.set_active_vectors('scalar_arr')
 
     assert grid.active_vectors_name == 'vector_arr'
@@ -607,7 +645,7 @@ def test_set_active_vectors_fail(grid):
 
 
 def test_set_active_tensors_fail(grid):
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.set_active_tensors('not a tensor')
 
     active_component_consistency_check(grid, "tensors", "point")
@@ -619,10 +657,10 @@ def test_set_active_tensors_fail(grid):
     grid.point_data['scalar_arr'] = np.zeros([grid.n_points])
     grid.point_data['vector_arr'] = np.zeros([grid.n_points, 3])
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.set_active_tensors('scalar_arr')
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.set_active_tensors('vector_arr')
 
     assert grid.active_tensors_name == 'tensor_arr'
@@ -725,7 +763,7 @@ def test_set_item(grid):
         grid['tmp'] = None
 
     # field data
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid['bad_field'] = range(5)
 
 
@@ -740,7 +778,7 @@ def test_str(grid):
 
 
 def test_set_cell_vectors(grid):
-    arr = np.random.random((grid.n_cells, 3))
+    arr = np.random.default_rng().random((grid.n_cells, 3))
     grid.cell_data['_cell_vectors'] = arr
     grid.set_active_vectors('_cell_vectors')
     assert grid.active_vectors_name == '_cell_vectors'
@@ -748,7 +786,7 @@ def test_set_cell_vectors(grid):
 
 
 def test_axis_rotation_invalid():
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         pv.axis_rotation(np.empty((3, 3)), 0, False, axis='not')
 
 
@@ -772,7 +810,7 @@ def test_bad_instantiation():
 
 
 def test_string_arrays():
-    poly = pv.PolyData(np.random.rand(10, 3))
+    poly = pv.PolyData(np.random.default_rng().random((10, 3)))
     arr = np.array([f'foo{i}' for i in range(10)])
     poly['foo'] = arr
     back = poly['foo']
@@ -784,9 +822,9 @@ def test_clear_data():
     grid = pv.ImageData(dimensions=(10, 10, 10))
     # Now try something more complicated
     grid.clear_data()
-    grid['foo-p'] = np.random.rand(grid.n_points)
-    grid['foo-c'] = np.random.rand(grid.n_cells)
-    grid.field_data['foo-f'] = np.random.rand(grid.n_points * grid.n_cells)
+    grid['foo-p'] = np.random.default_rng().random(grid.n_points)
+    grid['foo-c'] = np.random.default_rng().random(grid.n_cells)
+    grid.field_data['foo-f'] = np.random.default_rng().random(grid.n_points * grid.n_cells)
     assert grid.n_arrays == 3
     grid.clear_data()
     assert grid.n_arrays == 0
@@ -795,7 +833,10 @@ def test_clear_data():
 def test_scalars_dict_update():
     mesh = examples.load_uniform()
     n = len(mesh.point_data)
-    arrays = {'foo': np.arange(mesh.n_points), 'rand': np.random.random(mesh.n_points)}
+    arrays = {
+        'foo': np.arange(mesh.n_points),
+        'rand': np.random.default_rng().random(mesh.n_points),
+    }
     mesh.point_data.update(arrays)
     assert 'foo' in mesh.array_names
     assert 'rand' in mesh.array_names
@@ -861,7 +902,7 @@ def test_shallow_copy_back_propagation():
     # Case 2
     original = vtk.vtkPolyData()
     wrapped = pv.PolyData(original, deep=False)
-    wrapped.points = np.random.rand(5, 3)
+    wrapped.points = np.random.default_rng().random((5, 3))
     orig_points = vtk_to_numpy(original.GetPoints().GetData())
     assert np.allclose(orig_points, wrapped.points)
 
@@ -873,7 +914,7 @@ def test_find_closest_point():
     with pytest.raises(TypeError):
         sphere.find_closest_point([1, 2])
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         sphere.find_closest_point([0, 0, 0], n=0)
 
     with pytest.raises(TypeError):
@@ -973,7 +1014,6 @@ def test_find_cells_intersecting_line():
     else:
         with pytest.raises(VTKVersionError):
             indices = mesh.find_cells_intersecting_line(linea, lineb)
-            assert len(indices) == 1
 
 
 def test_find_cells_within_bounds():
@@ -1094,9 +1134,9 @@ def test_point_is_inside_cell():
     assert grid.point_is_inside_cell(0, np.array([0.5, 0.5, 0.5]))
 
     # cell ind out of range
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.point_is_inside_cell(100000, [0.5, 0.5, 0.5])
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.point_is_inside_cell(-1, [0.5, 0.5, 0.5])
 
     # cell ind wrong type
@@ -1106,7 +1146,7 @@ def test_point_is_inside_cell():
     # point not well formed
     with pytest.raises(TypeError):
         grid.point_is_inside_cell(0, 0.5)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         grid.point_is_inside_cell(0, [0.5, 0.5])
 
     # multi-dimensional
@@ -1162,16 +1202,16 @@ def test_multiprocessing(datasets, pickle_format):
     pv.set_pickle_format(pickle_format)
     with multiprocessing.Pool(2) as p:
         res = p.map(n_points, datasets)
-    for res, dataset in zip(res, datasets):
-        assert res == dataset.n_points
+    for re, dataset in zip(res, datasets):
+        assert re == dataset.n_points
 
 
 def test_rotations_should_match_by_a_360_degree_difference():
     mesh = examples.load_airplane()
 
-    point = np.random.random(3) - 0.5
-    angle = (np.random.random() - 0.5) * 360.0
-    vector = np.random.random(3) - 0.5
+    point = np.random.default_rng().random(3) - 0.5
+    angle = (np.random.default_rng().random() - 0.5) * 360.0
+    vector = np.random.default_rng().random(3) - 0.5
 
     # Rotate about x axis.
     rot1 = mesh.copy()
@@ -1209,7 +1249,7 @@ def test_rotate_x():
     assert isinstance(out, pv.StructuredGrid)
     with pytest.raises(TypeError):
         out = mesh.rotate_x(30, point=5)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         out = mesh.rotate_x(30, point=[1, 3])
 
 
@@ -1220,7 +1260,7 @@ def test_rotate_y():
     assert isinstance(out, pv.StructuredGrid)
     with pytest.raises(TypeError):
         out = mesh.rotate_y(30, point=5)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         out = mesh.rotate_y(30, point=[1, 3])
 
 
@@ -1231,7 +1271,7 @@ def test_rotate_z():
     assert isinstance(out, pv.StructuredGrid)
     with pytest.raises(TypeError):
         out = mesh.rotate_z(30, point=5)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         out = mesh.rotate_z(30, point=[1, 3])
 
 
@@ -1240,7 +1280,7 @@ def test_rotate_vector():
     mesh = examples.load_uniform()
     out = mesh.rotate_vector([1, 1, 1], 33)
     assert isinstance(out, pv.StructuredGrid)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         out = mesh.rotate_vector([1, 1], 33)
     with pytest.raises(TypeError):
         out = mesh.rotate_vector(30, 33)
@@ -1317,7 +1357,7 @@ def test_transform_integers_vtkbug_present():
 def test_scale():
     mesh = examples.load_airplane()
 
-    xyz = np.random.random(3)
+    xyz = np.random.default_rng().random(3)
     scale1 = mesh.copy()
     scale2 = mesh.copy()
     scale1.scale(xyz, inplace=True)
@@ -1413,7 +1453,8 @@ def test_active_normals(sphere):
 
 
 @pytest.mark.skipif(
-    pv.vtk_version_info < (9, 1, 0), reason="Requires VTK>=9.1.0 for a concrete PointSet class"
+    pv.vtk_version_info < (9, 1, 0),
+    reason="Requires VTK>=9.1.0 for a concrete PointSet class",
 )
 def test_cast_to_pointset(sphere):
     sphere = sphere.elevation()
@@ -1433,7 +1474,8 @@ def test_cast_to_pointset(sphere):
 
 
 @pytest.mark.skipif(
-    pv.vtk_version_info < (9, 1, 0), reason="Requires VTK>=9.1.0 for a concrete PointSet class"
+    pv.vtk_version_info < (9, 1, 0),
+    reason="Requires VTK>=9.1.0 for a concrete PointSet class",
 )
 def test_cast_to_pointset_implicit(uniform):
     pointset = uniform.cast_to_pointset(pass_cell_data=True)
@@ -1580,8 +1622,8 @@ def test_point_cell_ids(grid: DataSet, i0):
     cell_ids = grid.point_cell_ids(i0)
 
     assert isinstance(cell_ids, list)
-    assert all([isinstance(id, int) for id in cell_ids])
-    assert all([0 <= id < grid.n_cells for id in cell_ids])
+    assert all(isinstance(id_, int) for id_ in cell_ids)
+    assert all(0 <= id_ < grid.n_cells for id_ in cell_ids)
     assert len(cell_ids) > 0
 
     # Check that the output cells contain the i0-th point but also that the
@@ -1601,8 +1643,8 @@ def test_cell_point_neighbors_ids(grid: DataSet, i0):
     cell = grid.get_cell(i0)
 
     assert isinstance(cell_ids, list)
-    assert all([isinstance(id, int) for id in cell_ids])
-    assert all([0 <= id < grid.n_cells for id in cell_ids])
+    assert all(isinstance(id_, int) for id_ in cell_ids)
+    assert all(0 <= id_ < grid.n_cells for id_ in cell_ids)
     assert len(cell_ids) > 0
 
     # Check that all the neighbors cells share at least one point with the
@@ -1626,8 +1668,8 @@ def test_cell_edge_neighbors_ids(grid: DataSet, i0):
     cell = grid.get_cell(i0)
 
     assert isinstance(cell_ids, list)
-    assert all([isinstance(id, int) for id in cell_ids])
-    assert all([0 <= id < grid.n_cells for id in cell_ids])
+    assert all(isinstance(id_, int) for id_ in cell_ids)
+    assert all(0 <= id_ < grid.n_cells for id_ in cell_ids)
     assert len(cell_ids) > 0
 
     # Check that all the neighbors cells share at least one edge with the
@@ -1667,8 +1709,8 @@ def test_cell_face_neighbors_ids(grid: DataSet, i0):
     cell = grid.get_cell(i0)
 
     assert isinstance(cell_ids, list)
-    assert all([isinstance(id, int) for id in cell_ids])
-    assert all([0 <= id < grid.n_cells for id in cell_ids])
+    assert all(isinstance(id_, int) for id_ in cell_ids)
+    assert all(0 <= id_ < grid.n_cells for id_ in cell_ids)
     assert len(cell_ids) > 0
 
     # Check that all the neighbors cells share at least one face with the
@@ -1704,7 +1746,9 @@ def test_cell_face_neighbors_ids(grid: DataSet, i0):
 @pytest.mark.parametrize("i0", i0s, ids=lambda x: f"i0={x}")
 @pytest.mark.parametrize("n_levels", [1, 3], ids=lambda x: f"n_levels={x}")
 @pytest.mark.parametrize(
-    "connections", ["points", "edges", "faces"], ids=lambda x: f"connections={x}"
+    "connections",
+    ["points", "edges", "faces"],
+    ids=lambda x: f"connections={x}",
 )
 def test_cell_neighbors_levels(grid: DataSet, i0, n_levels, connections):
     cell_ids = grid.cell_neighbors_levels(i0, connections=connections, n_levels=n_levels)
@@ -1722,12 +1766,12 @@ def test_cell_neighbors_levels(grid: DataSet, i0, n_levels, connections):
         assert set(cell_ids) == set(grid.cell_neighbors(i0, connections=connections))
 
     else:
-        for i, ids in enumerate(cell_ids):
+        assert len(list(cell_ids)) == n_levels
+        for ids in cell_ids:
             assert isinstance(ids, list)
-            assert all([isinstance(id, int) for id in ids])
-            assert all([0 <= id < grid.n_cells for id in ids])
+            assert all(isinstance(id_, int) for id_ in ids)
+            assert all(0 <= id_ < grid.n_cells for id_ in ids)
             assert len(ids) > 0
-        assert i == n_levels - 1
 
 
 @pytest.mark.parametrize("grid", grids, ids=ids)
@@ -1746,12 +1790,12 @@ def test_point_neighbors_levels(grid: DataSet, i0, n_levels):
         assert set(point_ids) == set(grid.point_neighbors(i0))
 
     else:
-        for i, ids in enumerate(point_ids):
+        assert len(list(point_ids)) == n_levels
+        for ids in point_ids:
             assert isinstance(ids, list)
-            assert all([isinstance(id, int) for id in ids])
-            assert all([0 <= id < grid.n_points for id in ids])
+            assert all(isinstance(id_, int) for id_ in ids)
+            assert all(0 <= id_ < grid.n_points for id_ in ids)
             assert len(ids) > 0
-        assert i == n_levels - 1
 
 
 @pytest.fixture()
