@@ -1,37 +1,45 @@
+from __future__ import annotations
+
 import os
 import platform
-from string import ascii_letters, digits, whitespace
+from string import ascii_letters
+from string import digits
+from string import whitespace
 import sys
 
-from hypothesis import HealthCheck, given, settings
+from hypothesis import HealthCheck
+from hypothesis import given
+from hypothesis import settings
 from hypothesis.extra.numpy import arrays
-from hypothesis.strategies import integers, lists, text
+from hypothesis.strategies import integers
+from hypothesis.strategies import lists
+from hypothesis.strategies import text
 import numpy as np
 import pytest
-from pytest import fixture, mark, raises
 
 import pyvista as pv
 from pyvista.core.errors import PyVistaDeprecationWarning
-from pyvista.core.utilities.arrays import FieldAssociation, convert_array
+from pyvista.core.utilities.arrays import FieldAssociation
+from pyvista.core.utilities.arrays import convert_array
 
-skip_windows = mark.skipif(os.name == 'nt', reason='Test fails on Windows')
-skip_apple_silicon = mark.skipif(
+skip_windows = pytest.mark.skipif(os.name == 'nt', reason='Test fails on Windows')
+skip_apple_silicon = pytest.mark.skipif(
     platform.system() == 'Darwin' and platform.processor() == 'arm',
     reason='Test fails on Apple Silicon',
 )
 
 
-@fixture()
+@pytest.fixture()
 def hexbeam_point_attributes(hexbeam):
     return hexbeam.point_data
 
 
-@fixture()
+@pytest.fixture()
 def hexbeam_field_attributes(hexbeam):
     return hexbeam.field_data
 
 
-@fixture()
+@pytest.fixture()
 def insert_arange_narray(hexbeam_point_attributes):
     n_points = hexbeam_point_attributes.dataset.GetNumberOfPoints()
     sample_array = np.arange(n_points)
@@ -39,7 +47,7 @@ def insert_arange_narray(hexbeam_point_attributes):
     return hexbeam_point_attributes, sample_array
 
 
-@fixture()
+@pytest.fixture()
 def insert_bool_array(hexbeam_point_attributes):
     n_points = hexbeam_point_attributes.dataset.GetNumberOfPoints()
     sample_array = np.ones(n_points, np.bool_)
@@ -47,7 +55,7 @@ def insert_bool_array(hexbeam_point_attributes):
     return hexbeam_point_attributes, sample_array
 
 
-@fixture()
+@pytest.fixture()
 def insert_string_array(hexbeam_point_attributes):
     n_points = hexbeam_point_attributes.dataset.GetNumberOfPoints()
     sample_array = np.repeat("A", n_points)
@@ -57,7 +65,9 @@ def insert_string_array(hexbeam_point_attributes):
 
 def test_init(hexbeam):
     attributes = pv.DataSetAttributes(
-        hexbeam.GetPointData(), dataset=hexbeam, association=FieldAssociation.POINT
+        hexbeam.GetPointData(),
+        dataset=hexbeam,
+        association=FieldAssociation.POINT,
     )
     assert attributes.VTKObject == hexbeam.GetPointData()
     assert attributes.dataset == hexbeam
@@ -71,12 +81,12 @@ def test_bool(hexbeam_point_attributes):
 
 
 def test_getitem(hexbeam_point_attributes):
-    with raises(TypeError, match='Only strings'):
+    with pytest.raises(TypeError, match='Only strings'):
         hexbeam_point_attributes[0]
 
 
 def test_setitem(hexbeam_point_attributes):
-    with raises(TypeError, match='Only strings'):
+    with pytest.raises(TypeError, match='Only strings'):
         hexbeam_point_attributes[0]
 
 
@@ -97,11 +107,30 @@ def test_repr(hexbeam_point_attributes):
     assert str(data.dtype) in str(hexbeam_point_attributes)
 
     # ensure VECTOR in repr
-    vectors0 = np.random.random((sz, 3))
+    vectors0 = np.random.default_rng().random((sz, 3))
     hexbeam_point_attributes.set_vectors(vectors0, 'vectors0')
     assert 'VECTOR' in str(hexbeam_point_attributes)
 
 
+def test_repr_field_attributes_with_string(hexbeam_field_attributes):
+    repr_str = str(hexbeam_field_attributes)
+    assert 'DataSetAttributes' in repr_str
+    assert 'Contains arrays : None' in repr_str
+
+    # Add string data
+    str_len_18 = 'stringlength18char'
+    assert len(str_len_18) == 18
+    str_len_19 = 'stringlength19chars'
+    assert len(str_len_19) == 19
+
+    hexbeam_field_attributes['string_data_18'] = str_len_18
+    hexbeam_field_attributes['string_data_19'] = str_len_19
+
+    repr_str = str(hexbeam_field_attributes)
+    assert 'string_data_18          str        "stringlength18char"' in repr_str
+    assert 'string_data_19          str        "stringlength19c..."' in repr_str
+
+
 def test_empty_active_vectors(hexbeam):
     assert hexbeam.active_vectors is None
 
@@ -176,37 +205,37 @@ def test_eq(sphere):
 
 def test_add_matrix(hexbeam):
     mat_shape = (hexbeam.n_points, 3, 2)
-    mat = np.random.random(mat_shape)
+    mat = np.random.default_rng().random(mat_shape)
     hexbeam.point_data.set_array(mat, 'mat')
     matout = hexbeam.point_data['mat'].reshape(mat_shape)
     assert np.allclose(mat, matout)
 
 
 def test_set_fails_with_wrong_shape(hexbeam):
-    with raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         hexbeam['foo'] = [1, 2, 3]
-    with raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         hexbeam.point_data['foo'] = [1, 2, 3]
-    with raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         hexbeam.cell_data['foo'] = [1, 2, 3]
 
     # Use vtk methods directly to add bad data. This can simulate
     # cases where buggy vtk methods may set arrays with incorrect shape
     bad_data = convert_array([1, 2, 3], 'foo')
     hexbeam.cell_data.VTKObject.AddArray(bad_data)
-    with raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         hexbeam.cell_data['foo'] = hexbeam.cell_data['foo']
 
 
 def test_set_active_scalars_fail(hexbeam):
-    with raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         hexbeam.set_active_scalars('foo', preference='field')
-    with raises(KeyError):
+    with pytest.raises(KeyError):
         hexbeam.set_active_scalars('foo')
 
 
 def test_set_active_vectors(hexbeam):
-    vectors = np.random.random((hexbeam.n_points, 3))
+    vectors = np.random.default_rng().random((hexbeam.n_points, 3))
     hexbeam['vectors'] = vectors
     hexbeam.set_active_vectors('vectors')
     assert np.allclose(hexbeam.active_vectors, vectors)
@@ -214,7 +243,7 @@ def test_set_active_vectors(hexbeam):
 
 def test_set_vectors(hexbeam):
     assert hexbeam.point_data.active_vectors is None
-    vectors = np.random.random((hexbeam.n_points, 3))
+    vectors = np.random.default_rng().random((hexbeam.n_points, 3))
     hexbeam.point_data.set_vectors(vectors, 'my-vectors')
     assert np.allclose(hexbeam.point_data.active_vectors, vectors)
 
@@ -225,8 +254,8 @@ def test_set_vectors(hexbeam):
 
 def test_set_invalid_vectors(hexbeam):
     # verify non-vector data does not become active vectors
-    not_vectors = np.random.random(hexbeam.n_points)
-    with raises(ValueError):
+    not_vectors = np.random.default_rng().random(hexbeam.n_points)
+    with pytest.raises(ValueError):  # noqa: PT011
         hexbeam.point_data.set_vectors(not_vectors, 'my-vectors')
 
 
@@ -259,9 +288,9 @@ def test_set_bitarray(hexbeam):
     assert hexbeam.point_data['bitarray'].dtype == np.int32
 
 
-@mark.parametrize('array_key', ['invalid_array_name', -1])
+@pytest.mark.parametrize('array_key', ['invalid_array_name', -1])
 def test_get_array_should_fail_if_does_not_exist(array_key, hexbeam_point_attributes):
-    with raises(KeyError):
+    with pytest.raises(KeyError):
         hexbeam_point_attributes.get_array(array_key)
 
 
@@ -278,7 +307,7 @@ def test_get_array_bool_array_should_be_identical(insert_bool_array):
 
 
 def test_add_should_not_add_none_array(hexbeam_point_attributes):
-    with raises(TypeError):
+    with pytest.raises(TypeError):
         hexbeam_point_attributes.set_array(None, 'sample_array')
 
 
@@ -306,7 +335,7 @@ def test_contains_should_contain_when_added(insert_arange_narray):
 
 def test_set_array_catch(hexbeam):
     data = np.zeros(hexbeam.n_points)
-    with raises(TypeError, match='`name` must be a string'):
+    with pytest.raises(TypeError, match='`name` must be a string'):
         hexbeam.point_data.set_array(data, name=['foo'])
 
 
@@ -335,7 +364,7 @@ def test_set_array_string_lists_should_equal(arr, hexbeam_field_attributes):
 @given(arr=arrays(dtype='U', shape=10))
 def test_set_array_string_array_should_equal(arr, hexbeam_field_attributes):
     if not ''.join(arr).isascii():
-        with raises(ValueError, match='non-ASCII'):
+        with pytest.raises(ValueError, match='non-ASCII'):
             hexbeam_field_attributes['string_arr'] = arr
         return
 
@@ -344,8 +373,8 @@ def test_set_array_string_array_should_equal(arr, hexbeam_field_attributes):
 
 
 def test_hexbeam_field_attributes_active_scalars(hexbeam_field_attributes):
-    with raises(TypeError):
-        hexbeam_field_attributes.active_scalars
+    with pytest.raises(TypeError):
+        _ = hexbeam_field_attributes.active_scalars
 
 
 def test_should_remove_array(insert_arange_narray):
@@ -392,33 +421,33 @@ def test_should_pop_array_invalid(insert_arange_narray):
     assert dsa.pop(key, default) is default
 
 
-@mark.parametrize('removed_key', [None, 'nonexistent_array_name', '', -1])
+@pytest.mark.parametrize('removed_key', [None, 'nonexistent_array_name', '', -1])
 def test_remove_should_fail_on_bad_argument(removed_key, hexbeam_point_attributes):
     if removed_key in [None, -1]:
-        with raises(TypeError):
+        with pytest.raises(TypeError):
             hexbeam_point_attributes.remove(removed_key)
     else:
-        with raises(KeyError):
+        with pytest.raises(KeyError):
             hexbeam_point_attributes.remove(removed_key)
 
 
-@mark.parametrize('removed_key', [None, 'nonexistent_array_name', '', -1])
+@pytest.mark.parametrize('removed_key', [None, 'nonexistent_array_name', '', -1])
 def test_del_should_fail_bad_argument(removed_key, hexbeam_point_attributes):
     if removed_key in [None, -1]:
-        with raises(TypeError):
+        with pytest.raises(TypeError):
             del hexbeam_point_attributes[removed_key]
     else:
-        with raises(KeyError):
+        with pytest.raises(KeyError):
             del hexbeam_point_attributes[removed_key]
 
 
-@mark.parametrize('removed_key', [None, 'nonexistent_array_name', '', -1])
+@pytest.mark.parametrize('removed_key', [None, 'nonexistent_array_name', '', -1])
 def test_pop_should_fail_bad_argument(removed_key, hexbeam_point_attributes):
     if removed_key in [None, -1]:
-        with raises(TypeError):
+        with pytest.raises(TypeError):
             hexbeam_point_attributes.pop(removed_key)
     else:
-        with raises(KeyError):
+        with pytest.raises(KeyError):
             hexbeam_point_attributes.pop(removed_key)
 
 
@@ -496,7 +525,7 @@ def test_active_scalars_setter_no_override(hexbeam):
 @given(arr=arrays(dtype='U', shape=10))
 def test_preserve_field_data_after_extract_cells(hexbeam, arr):
     if not ''.join(arr).isascii():
-        with raises(ValueError, match='non-ASCII'):
+        with pytest.raises(ValueError, match='non-ASCII'):
             hexbeam.field_data["foo"] = arr
         return
 
@@ -529,11 +558,11 @@ def test_normals_set():
     plane.point_data.normals = plane.point_normals
     assert np.array_equal(plane.point_data.active_normals, plane.point_normals)
 
-    with raises(ValueError, match='must be a 2-dim'):
+    with pytest.raises(ValueError, match='must be a 2-dim'):
         plane.point_data.active_normals = [1]
-    with raises(ValueError, match='must match number of points'):
+    with pytest.raises(ValueError, match='must match number of points'):
         plane.point_data.active_normals = [[1, 1, 1], [0, 0, 0]]
-    with raises(ValueError, match='Normals must have exactly 3 components'):
+    with pytest.raises(ValueError, match='Normals must have exactly 3 components'):
         plane.point_data.active_normals = [[1, 1], [0, 0], [0, 0], [0, 0]]
 
 
@@ -548,8 +577,8 @@ def test_normals_name(plane):
 
 
 def test_normals_raise_field(plane):
-    with raises(AttributeError):
-        plane.field_data.active_normals
+    with pytest.raises(AttributeError):
+        _ = plane.field_data.active_normals
 
 
 def test_add_two_vectors():
@@ -557,9 +586,9 @@ def test_add_two_vectors():
     mesh = pv.Plane(i_resolution=1, j_resolution=1)
     mesh.point_data.set_array(range(4), 'my-scalars')
     mesh.point_data.set_array(range(5, 9), 'my-other-scalars')
-    vectors0 = np.random.random((4, 3))
+    vectors0 = np.random.default_rng().random((4, 3))
     mesh.point_data.set_vectors(vectors0, 'vectors0')
-    vectors1 = np.random.random((4, 3))
+    vectors1 = np.random.default_rng().random((4, 3))
     mesh.point_data.set_vectors(vectors1, 'vectors1')
 
     assert 'vectors0' in mesh.point_data
@@ -569,27 +598,27 @@ def test_add_two_vectors():
 def test_active_vectors_name_setter():
     mesh = pv.Plane(i_resolution=1, j_resolution=1)
     mesh.point_data.set_array(range(4), 'my-scalars')
-    vectors0 = np.random.random((4, 3))
+    vectors0 = np.random.default_rng().random((4, 3))
     mesh.point_data.set_vectors(vectors0, 'vectors0')
-    vectors1 = np.random.random((4, 3))
+    vectors1 = np.random.default_rng().random((4, 3))
     mesh.point_data.set_vectors(vectors1, 'vectors1')
 
     assert mesh.point_data.active_vectors_name == 'vectors1'
     mesh.point_data.active_vectors_name = 'vectors0'
     assert mesh.point_data.active_vectors_name == 'vectors0'
 
-    with raises(KeyError, match='does not contain'):
+    with pytest.raises(KeyError, match='does not contain'):
         mesh.point_data.active_vectors_name = 'not a valid key'
 
-    with raises(ValueError, match='needs 3 components'):
+    with pytest.raises(ValueError, match='needs 3 components'):
         mesh.point_data.active_vectors_name = 'my-scalars'
 
 
 def test_active_vectors_eq():
     mesh = pv.Plane(i_resolution=1, j_resolution=1)
-    vectors0 = np.random.random((4, 3))
+    vectors0 = np.random.default_rng().random((4, 3))
     mesh.point_data.set_vectors(vectors0, 'vectors0')
-    vectors1 = np.random.random((4, 3))
+    vectors1 = np.random.default_rng().random((4, 3))
     mesh.point_data.set_vectors(vectors1, 'vectors1')
 
     other_mesh = mesh.copy(deep=True)
@@ -603,28 +632,28 @@ def test_active_texture_coordinates_name(plane):
     plane.point_data['arr'] = plane.point_data.active_texture_coordinates
     plane.point_data.active_texture_coordinates_name = 'arr'
 
-    with raises(AttributeError):
+    with pytest.raises(AttributeError):
         plane.field_data.active_texture_coordinates_name = 'arr'
 
 
 @skip_windows  # windows doesn't support np.complex256
 @skip_apple_silicon  # same with Apple silicon (M1/M2)
 def test_complex_raises(plane):
-    with raises(ValueError, match='Only numpy.complex64'):
+    with pytest.raises(ValueError, match='Only numpy.complex64'):
         plane.point_data['data'] = np.empty(plane.n_points, dtype=np.complex256)
 
 
-@mark.parametrize('dtype_str', ['complex64', 'complex128'])
+@pytest.mark.parametrize('dtype_str', ['complex64', 'complex128'])
 def test_complex(plane, dtype_str):
     """Test if complex data can be properly represented in datasetattributes."""
     dtype = np.dtype(dtype_str)
     name = 'my_data'
 
-    with raises(ValueError, match='Complex data must be single dimensional'):
+    with pytest.raises(ValueError, match='Complex data must be single dimensional'):
         plane.point_data[name] = np.empty((plane.n_points, 2), dtype=dtype)
 
     real_type = np.float32 if dtype == np.complex64 else np.float64
-    data = np.random.random((plane.n_points, 2)).astype(real_type).view(dtype).ravel()
+    data = np.random.default_rng().random((plane.n_points, 2)).astype(real_type).view(dtype).ravel()
     plane.point_data[name] = data
     assert np.array_equal(plane.point_data[name], data)
 
