@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from itertools import permutations
 import re
 
@@ -38,7 +40,8 @@ def test_sphere():
 
 
 @pytest.mark.parametrize(
-    'expected', [[1, 0, 0], [0, 1, 0], [0, 0, 1], [-1, 0, 0], [0, -1, 0], [0, 0, -1]]
+    'expected',
+    [[1, 0, 0], [0, 1, 0], [0, 0, 1], [-1, 0, 0], [0, -1, 0], [0, 0, -1]],
 )
 def test_sphere_direction_points(expected):
     # from south pole to north pole
@@ -83,7 +86,7 @@ def test_solid_sphere():
     assert np.any(sphere.points)
 
     # make sure cell creation gives positive volume.
-    for i, cell in enumerate(sphere.cell):
+    for cell in sphere.cell:
         assert cell.cast_to_unstructured_grid().volume > 0
     sphere = pv.SolidSphere(radius_resolution=5, theta_resolution=100, phi_resolution=100)
     assert sphere.volume == pytest.approx(4.0 / 3.0 * np.pi * 0.5**3, rel=1e-3)
@@ -103,14 +106,20 @@ def test_solid_sphere_hollow():
 def test_solid_sphere_generic():
     sphere = pv.SolidSphere(radius_resolution=5, theta_resolution=11, phi_resolution=13)
     sphere_seq = pv.SolidSphereGeneric(
-        radius=np.linspace(0, 0.5, 5), theta=np.linspace(0, 360, 11), phi=np.linspace(0, 180, 13)
+        radius=np.linspace(0, 0.5, 5),
+        theta=np.linspace(0, 360, 11),
+        phi=np.linspace(0, 180, 13),
     )
     assert sphere == sphere_seq
 
 
 def test_solid_sphere_theta_start_end():
     sphere = pv.SolidSphere(
-        start_theta=0, end_theta=180, radius_resolution=5, theta_resolution=100, phi_resolution=100
+        start_theta=0,
+        end_theta=180,
+        radius_resolution=5,
+        theta_resolution=100,
+        phi_resolution=100,
     )
     assert sphere.volume == pytest.approx(4.0 / 3.0 * np.pi * 0.5**3 / 2, rel=1e-3)
 
@@ -124,7 +133,11 @@ def test_solid_sphere_theta_start_end():
     assert sphere.volume == pytest.approx(4.0 / 3.0 * np.pi * 0.5**3 / 2, rel=1e-3)
 
     sphere = pv.SolidSphere(
-        start_theta=90, end_theta=120, radius_resolution=5, theta_resolution=100, phi_resolution=100
+        start_theta=90,
+        end_theta=120,
+        radius_resolution=5,
+        theta_resolution=100,
+        phi_resolution=100,
     )
     assert sphere.volume == pytest.approx(4.0 / 3.0 * np.pi * 0.5**3 / 12, rel=1e-3)
 
@@ -133,7 +146,11 @@ def test_solid_sphere_phi_start_end():
     exp_sphere_volume = 4.0 / 3.0 * np.pi * 0.5**3
 
     sphere = pv.SolidSphere(
-        start_phi=0, end_phi=90, radius_resolution=5, theta_resolution=100, phi_resolution=100
+        start_phi=0,
+        end_phi=90,
+        radius_resolution=5,
+        theta_resolution=100,
+        phi_resolution=100,
     )
     assert sphere.volume == pytest.approx(exp_sphere_volume / 2, rel=1e-3)
 
@@ -188,7 +205,8 @@ def test_solid_sphere_resolution_errors():
     with pytest.raises(ValueError, match="maximum phi cannot be > 180"):
         pv.SolidSphere(end_phi=190)
     with pytest.raises(
-        ValueError, match=re.escape("max theta and min theta must be within 2 * np.pi")
+        ValueError,
+        match=re.escape("max theta and min theta must be within 2 * np.pi"),
     ):
         pv.SolidSphere(end_theta=2.1 * np.pi, radians=True)
     with pytest.raises(ValueError, match="maximum phi cannot be > np.pi"):
@@ -284,7 +302,7 @@ def test_solid_sphere_tol_radius():
     assert np.array_equal(solid_sphere.points[0, :], [0.0, 0.0, 1.0e-10])
 
 
-@pytest.mark.parametrize("radians", (True, False))
+@pytest.mark.parametrize("radians", [True, False])
 def test_solid_sphere_tol_angle(radians):
     max_phi = np.pi if radians else 180.0
 
@@ -299,13 +317,19 @@ def test_solid_sphere_tol_angle(radians):
     assert solid_sphere.points[2, 2] > 0.0
 
     solid_sphere = pv.SolidSphere(
-        start_phi=1e-3, radius_resolution=2, radians=radians, tol_angle=1e-2
+        start_phi=1e-3,
+        radius_resolution=2,
+        radians=radians,
+        tol_angle=1e-2,
     )
     # Positive axis point is there, but it is now slightly offset.
     assert np.allclose(solid_sphere.points[1, :], [0.0, 0.0, 0.5], atol=1e-3)
     # Negative axis point is there
     solid_sphere = pv.SolidSphere(
-        end_phi=max_phi - 1e-3, radius_resolution=2, radians=radians, tol_angle=1e-2
+        end_phi=max_phi - 1e-3,
+        radius_resolution=2,
+        radians=radians,
+        tol_angle=1e-2,
     )
     assert np.allclose(solid_sphere.points[2, :], [0.0, 0.0, -0.5], atol=1e-3)
 
@@ -325,7 +349,8 @@ def test_plane():
 
 
 @pytest.mark.parametrize(
-    'expected', [[1, 0, 0], [0, 1, 0], [0, 0, 1], [-1, 0, 0], [0, -1, 0], [0, 0, -1]]
+    'expected',
+    [[1, 0, 0], [0, 1, 0], [0, 0, 1], [-1, 0, 0], [0, -1, 0], [0, 0, -1]],
 )
 def test_plane_direction(expected):
     surf = pv.Plane(direction=expected)
@@ -351,7 +376,7 @@ def test_line():
     assert line.n_points == 11
     assert line.n_cells == 1
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         pv.Line(pointa, pointb, -1)
 
     with pytest.raises(TypeError):
@@ -373,10 +398,10 @@ def test_multiple_lines():
     points = np.array([[0, 0, 0], [1, 1 * np.sqrt(3), 0], [2, 0, 0], [3, 3 * np.sqrt(3), 0]])
     multiple_lines = pv.MultipleLines(points=points)
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         pv.MultipleLines(points[:, :1])
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         pv.MultipleLines(points[0, :])
 
 
@@ -391,7 +416,7 @@ def test_tube():
     assert tube.n_points == 165
     assert tube.n_cells == 15
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         pv.Tube(pointa, pointb, -1)
 
     with pytest.raises(TypeError):
@@ -404,6 +429,21 @@ def test_tube():
         pv.Tube(pointa, (10, 1.0))
 
 
+def test_capsule():
+    capsule = pv.Capsule()
+    assert np.any(capsule.points)
+    assert np.any(capsule.faces)
+
+
+# https://github.com/pyvista/pyvista/pull/6119
+@pytest.mark.parametrize('center', [(4, 5, 6), (1, 1, 1)])
+@pytest.mark.parametrize('direction', [(0, 1, -1), (1, 1, 0)])
+def test_capsule_center(center, direction):
+    capsule = pv.Capsule(center, direction)
+    cylinder = pv.Cylinder(center, direction)
+    assert np.allclose(capsule.center, cylinder.center)
+
+
 def test_cube():
     cube = pv.Cube()
     assert np.any(cube.points)
@@ -415,6 +455,16 @@ def test_cube():
     assert np.allclose(cube.bounds, bounds)
 
 
+@pytest.mark.parametrize(('point_dtype'), (['float32', 'float64', 'invalid']))
+def test_cube_point_dtype(point_dtype):
+    if point_dtype in ['float32', 'float64']:
+        cube = pv.Cube(point_dtype=point_dtype)
+        assert cube.points.dtype == point_dtype
+    else:
+        with pytest.raises(ValueError, match="Point dtype must be either 'float32' or 'float64'"):
+            _ = pv.Cube(point_dtype=point_dtype)
+
+
 def test_cone():
     cone = pv.Cone()
     assert np.any(cone.points)
@@ -490,10 +540,10 @@ def test_text_3d():
         bnds[3] - bnds[2],
         bnds[5] - bnds[4],
     )
-    assert actual_width == 2
-    assert actual_height == 3
-    assert actual_depth == 0.5
-    assert mesh.center == [1.0, 2.0, 3.0]
+    assert np.isclose(actual_width, 2.0)
+    assert np.isclose(actual_height, 3.0)
+    assert np.isclose(actual_depth, 0.5)
+    assert np.allclose(mesh.center, [1.0, 2.0, 3.0])
 
     # Test setting empty string returns empty mesh with zeros as bounds
     mesh = pv.Text3D(string="")
@@ -520,7 +570,7 @@ def test_circular_arc():
     assert np.allclose(mesh['Distance'], distance)
 
     # pointa and pointb are not equidistant from center
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         mesh = pv.CircularArc([-1, 0, 0], [-0.99, 0.001, 0], [0, 0, 0], 100)
 
 
@@ -599,7 +649,8 @@ def test_rectangle(points):
     # Do a rotation to be in full 3D space with floating point coordinates
     trans = pv.core.utilities.transformations.axis_angle_rotation([1, 1, 1], 30)
     rotated = pv.core.utilities.transformations.apply_transformation_to_points(
-        trans, np.array([pointa, pointb, pointc, pointd])
+        trans,
+        np.array([pointa, pointb, pointc, pointd]),
     )
 
     # Test all possible orders of the points
@@ -618,7 +669,8 @@ def test_rectangle_not_orthognal_entries():
     # Do a rotation to be in full 3D space with floating point coordinates
     trans = pv.core.utilities.transformations.axis_angle_rotation([1, 1, 1], 30)
     rotated = pv.core.utilities.transformations.apply_transformation_to_points(
-        trans, np.array([pointa, pointb, pointc])
+        trans,
+        np.array([pointa, pointb, pointc]),
     )
 
     with pytest.raises(ValueError, match="The three points should defined orthogonal vectors"):
@@ -633,11 +685,13 @@ def test_rectangle_two_identical_points():
     # Do a rotation to be in full 3D space with floating point coordinates
     trans = pv.core.utilities.transformations.axis_angle_rotation([1, 1, 1], 30)
     rotated = pv.core.utilities.transformations.apply_transformation_to_points(
-        trans, np.array([pointa, pointb, pointc])
+        trans,
+        np.array([pointa, pointb, pointc]),
     )
 
     with pytest.raises(
-        ValueError, match="Unable to build a rectangle with less than three different points"
+        ValueError,
+        match="Unable to build a rectangle with less than three different points",
     ):
         pv.Rectangle(rotated)
 
@@ -679,7 +733,7 @@ def test_ellipse():
 
 
 @pytest.mark.parametrize(
-    'kind_str, kind_int, n_vertices, n_faces',
+    ('kind_str', 'kind_int', 'n_vertices', 'n_faces'),
     zip(
         ['tetrahedron', 'cube', 'octahedron', 'icosahedron', 'dodecahedron'],
         range(5),
@@ -699,11 +753,11 @@ def test_platonic_solids(kind_str, kind_int, n_vertices, n_faces):
 
 
 def test_platonic_invalids():
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         pv.PlatonicSolid(kind='invalid')
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         pv.PlatonicSolid(kind=42)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         pv.PlatonicSolid(kind=[])
 
 
