@@ -1,6 +1,9 @@
+from __future__ import annotations
+
 import pytest
 
 import pyvista as pv
+from pyvista import examples
 from pyvista.core.errors import MissingDataError
 
 
@@ -11,7 +14,7 @@ def test_contour_banded_raise(sphere):
         sphere.contour_banded(5)
 
     sphere['data'] = sphere.points[:, 2]
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         sphere.contour_banded(5, scalar_mode='foo')
 
     sphere.clear_data()
@@ -33,7 +36,11 @@ def test_contour_banded_points(sphere):
 
     rng = [-100, 100]
     out = sphere.contour_banded(
-        10, rng=rng, generate_contour_edges=False, scalar_mode='index', clipping=True
+        10,
+        rng=rng,
+        generate_contour_edges=False,
+        scalar_mode='index',
+        clipping=True,
     )
     assert out['data'].min() <= rng[0]
     assert out['data'].max() >= rng[1]
@@ -50,3 +57,20 @@ def test_boolean_intersect_edge_case():
 def test_identical_boolean(sphere):
     with pytest.raises(ValueError, match='identical points'):
         sphere.boolean_intersection(sphere.copy())
+
+
+def test_triangulate_contours():
+    poly = pv.Polygon(n_sides=4, fill=False)
+    filled = poly.triangulate_contours()
+    for cell in filled.cell:
+        assert cell.type == pv.CellType.TRIANGLE
+
+
+@pytest.mark.skipif(
+    pv.vtk_version_info < (9, 1, 0),
+    reason="Requires VTK>=9.1.0 for a vtkIOChemistry.vtkCMLMoleculeReader",
+)
+def test_protein_ribbon():
+    tgqp = examples.download_3gqp()
+    ribbon = tgqp.protein_ribbon()
+    assert ribbon.n_cells
