@@ -1,9 +1,13 @@
 """Test pyvista core utilities."""
+
+from __future__ import annotations
+
+import json
 import os
-import pathlib
+from pathlib import Path
 import pickle
 import shutil
-import unittest.mock as mock
+from unittest import mock
 import warnings
 
 import numpy as np
@@ -11,25 +15,27 @@ import pytest
 import vtk
 
 import pyvista as pv
-from pyvista import examples as ex, pyvista_ndarray
-from pyvista.core.utilities import cells, fileio, fit_plane_to_points, transformations
-from pyvista.core.utilities.arrays import (
-    _coerce_pointslike_arg,
-    _coerce_transformlike_arg,
-    cast_to_list_array,
-    cast_to_ndarray,
-    cast_to_tuple_array,
-    copy_vtk_array,
-    get_array,
-    has_duplicates,
-    raise_has_duplicates,
-    vtk_id_list_to_array,
-    vtkmatrix_from_array,
-)
+from pyvista import examples as ex
+from pyvista.core.utilities import cells
+from pyvista.core.utilities import fileio
+from pyvista.core.utilities import fit_plane_to_points
+from pyvista.core.utilities import transformations
+from pyvista.core.utilities.arrays import _coerce_pointslike_arg
+from pyvista.core.utilities.arrays import _coerce_transformlike_arg
+from pyvista.core.utilities.arrays import _SerializedDictArray
+from pyvista.core.utilities.arrays import copy_vtk_array
+from pyvista.core.utilities.arrays import get_array
+from pyvista.core.utilities.arrays import has_duplicates
+from pyvista.core.utilities.arrays import raise_has_duplicates
+from pyvista.core.utilities.arrays import vtk_id_list_to_array
+from pyvista.core.utilities.arrays import vtkmatrix_from_array
 from pyvista.core.utilities.docs import linkcode_resolve
 from pyvista.core.utilities.fileio import get_ext
 from pyvista.core.utilities.helpers import is_inside_bounds
-from pyvista.core.utilities.misc import assert_empty_kwargs, check_valid_vector, has_module
+from pyvista.core.utilities.misc import assert_empty_kwargs
+from pyvista.core.utilities.misc import check_valid_vector
+from pyvista.core.utilities.misc import has_module
+from pyvista.core.utilities.misc import no_new_attr
 from pyvista.core.utilities.observers import Observer
 from pyvista.core.utilities.points import vector_poly_data
 
@@ -50,30 +56,30 @@ def test_version():
 
 
 def test_createvectorpolydata_error():
-    orig = np.random.random((3, 1))
-    vec = np.random.random((3, 1))
-    with pytest.raises(ValueError):
+    orig = np.random.default_rng().random((3, 1))
+    vec = np.random.default_rng().random((3, 1))
+    with pytest.raises(ValueError):  # noqa: PT011
         vector_poly_data(orig, vec)
 
 
 def test_createvectorpolydata_1D():
-    orig = np.random.random(3)
-    vec = np.random.random(3)
+    orig = np.random.default_rng().random(3)
+    vec = np.random.default_rng().random(3)
     vdata = vector_poly_data(orig, vec)
     assert np.any(vdata.points)
     assert np.any(vdata.point_data['vectors'])
 
 
 def test_createvectorpolydata():
-    orig = np.random.random((100, 3))
-    vec = np.random.random((100, 3))
+    orig = np.random.default_rng().random((100, 3))
+    vec = np.random.default_rng().random((100, 3))
     vdata = vector_poly_data(orig, vec)
     assert np.any(vdata.points)
     assert np.any(vdata.point_data['vectors'])
 
 
 @pytest.mark.parametrize(
-    'path, target_ext',
+    ('path', 'target_ext'),
     [
         ("/data/mesh.stl", ".stl"),
         ("/data/image.nii.gz", '.nii.gz'),
@@ -89,7 +95,7 @@ def test_get_ext(path, target_ext):
 def test_read(tmpdir, use_pathlib):
     fnames = (ex.antfile, ex.planefile, ex.hexbeamfile, ex.spherefile, ex.uniformfile, ex.rectfile)
     if use_pathlib:
-        fnames = [pathlib.Path(fname) for fname in fnames]
+        fnames = [Path(fname) for fname in fnames]
     types = (
         pv.PolyData,
         pv.PolyData,
@@ -103,12 +109,12 @@ def test_read(tmpdir, use_pathlib):
         assert isinstance(obj, types[i])
     # this is also tested for each mesh types init from file tests
     filename = str(tmpdir.mkdir("tmpdir").join('tmp.npy'))
-    arr = np.random.rand(10, 10)
+    arr = np.random.default_rng().random((10, 10))
     np.save(filename, arr)
-    with pytest.raises(IOError):
+    with pytest.raises(IOError):  # noqa: PT011
         _ = pv.read(filename)
     # read non existing file
-    with pytest.raises(IOError):
+    with pytest.raises(IOError):  # noqa: PT011
         _ = pv.read('this_file_totally_does_not_exist.vtk')
     # Now test reading lists of files as multi blocks
     multi = pv.read(fnames)
@@ -135,13 +141,15 @@ def test_read_force_ext(tmpdir):
     )
 
     dummy_extension = '.dummy'
-    for fname, type in zip(fnames, types):
-        root, original_ext = os.path.splitext(fname)
+    for fname, type_ in zip(fnames, types):
+        path = Path(fname)
+        root = str(path.parent / path.stem)
+        original_ext = path.suffix
         _, name = os.path.split(root)
         new_fname = tmpdir / name + '.' + dummy_extension
         shutil.copy(fname, new_fname)
         data = fileio.read(new_fname, force_ext=original_ext)
-        assert isinstance(data, type)
+        assert isinstance(data, type_)
 
 
 @mock.patch('pyvista.BaseReader.read')
@@ -174,7 +182,7 @@ def test_read_force_ext_wrong_extension(tmpdir):
     assert len(data) == 0
 
     fname = ex.planefile
-    with pytest.raises(IOError):
+    with pytest.raises(IOError):  # noqa: PT011
         fileio.read(fname, force_ext='.not_supported')
 
 
@@ -185,11 +193,11 @@ def test_pyvista_read_exodus(read_exodus_mock):
     pv.read(ex.globefile, force_ext='.e')
     args, kwargs = read_exodus_mock.call_args
     filename = args[0]
-    assert filename == ex.globefile
+    assert filename == Path(ex.globefile)
 
 
 def test_get_array_cell(hexbeam):
-    carr = np.random.rand(hexbeam.n_cells)
+    carr = np.random.default_rng().random(hexbeam.n_cells)
     hexbeam.cell_data.set_array(carr, 'test_data')
 
     data = get_array(hexbeam, 'test_data', preference='cell')
@@ -197,13 +205,13 @@ def test_get_array_cell(hexbeam):
 
 
 def test_get_array_point(hexbeam):
-    parr = np.random.rand(hexbeam.n_points)
+    parr = np.random.default_rng().random(hexbeam.n_points)
     hexbeam.point_data.set_array(parr, 'test_data')
 
     data = get_array(hexbeam, 'test_data', preference='point')
     assert np.allclose(parr, data)
 
-    oarr = np.random.rand(hexbeam.n_points)
+    oarr = np.random.default_rng().random(hexbeam.n_points)
     hexbeam.point_data.set_array(oarr, 'other')
 
     data = get_array(hexbeam, 'other')
@@ -213,26 +221,26 @@ def test_get_array_point(hexbeam):
 def test_get_array_field(hexbeam):
     hexbeam.clear_data()
     # no preference
-    farr = np.random.rand(hexbeam.n_points * hexbeam.n_cells)
+    farr = np.random.default_rng().random(hexbeam.n_points * hexbeam.n_cells)
     hexbeam.field_data.set_array(farr, 'data')
     data = get_array(hexbeam, 'data')
     assert np.allclose(farr, data)
 
     # preference and multiple data
-    hexbeam.point_data.set_array(np.random.rand(hexbeam.n_points), 'data')
+    hexbeam.point_data.set_array(np.random.default_rng().random(hexbeam.n_points), 'data')
 
     data = get_array(hexbeam, 'data', preference='field')
     assert np.allclose(farr, data)
 
 
 def test_get_array_error(hexbeam):
-    parr = np.random.rand(hexbeam.n_points)
+    parr = np.random.default_rng().random(hexbeam.n_points)
     hexbeam.point_data.set_array(parr, 'test_data')
 
     # invalid inputs
     with pytest.raises(TypeError):
         get_array(hexbeam, 'test_data', preference={'invalid'})
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         get_array(hexbeam, 'test_data', preference='invalid')
     with pytest.raises(ValueError, match='`preference` must be'):
         get_array(hexbeam, 'test_data', preference='row')
@@ -283,8 +291,8 @@ def test_voxelize_invalid_density(rectilinear):
 
 
 def test_voxelize_throws_point_cloud(hexbeam):
+    mesh = pv.PolyData(hexbeam.points)
     with pytest.raises(ValueError, match='must have faces'):
-        mesh = pv.PolyData(hexbeam.points)
         pv.voxelize(mesh)
 
 
@@ -403,21 +411,21 @@ def test_vtkmatrix_to_from_array():
             assert array[i, j] == matrix.GetElement(i, j)
 
     # invalid cases
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         matrix = pv.vtkmatrix_from_array(np.arange(3 * 4).reshape(3, 4))
+    invalid = vtk.vtkTransform()
     with pytest.raises(TypeError):
-        invalid = vtk.vtkTransform()
         array = pv.array_from_vtkmatrix(invalid)
 
 
 def test_assert_empty_kwargs():
     kwargs = {}
     assert assert_empty_kwargs(**kwargs)
+    kwargs = {"foo": 6}
     with pytest.raises(TypeError):
-        kwargs = {"foo": 6}
         assert_empty_kwargs(**kwargs)
+    kwargs = {"foo": 6, "goo": "bad"}
     with pytest.raises(TypeError):
-        kwargs = {"foo": 6, "goo": "bad"}
         assert_empty_kwargs(**kwargs)
 
 
@@ -467,10 +475,10 @@ def test_check_valid_vector():
 
 def test_cells_dict_utils():
     # No pyvista object
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         cells.get_mixed_cells(None)
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         cells.get_mixed_cells(np.zeros(shape=[3, 3]))
 
 
@@ -565,16 +573,16 @@ def test_axis_angle_rotation():
     assert np.allclose(actual, expected)
 
     # invalid cases
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         transformations.axis_angle_rotation([1, 0, 0, 0], angle)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         transformations.axis_angle_rotation(axis, angle, point=[1, 0, 0, 0])
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         transformations.axis_angle_rotation([0, 0, 0], angle)
 
 
 @pytest.mark.parametrize(
-    "axis,angle,times",
+    ("axis", "angle", "times"),
     [
         ([1, 0, 0], 90, 4),
         ([1, 0, 0], 180, 2),
@@ -605,7 +613,7 @@ def test_reflection():
             [-1, 1, 0],
             [-1, -1, 0],
             [1, -1, 0],
-        ]
+        ],
     )
     normal = [1, 1, 0]
 
@@ -623,11 +631,11 @@ def test_reflection():
     assert np.allclose(actual, expected)
 
     # invalid cases
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         transformations.reflection([1, 0, 0, 0])
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         transformations.reflection(normal, point=[1, 0, 0, 0])
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         transformations.reflection([0, 0, 0])
 
 
@@ -684,7 +692,8 @@ def test_convert_array():
 
     # https://github.com/pyvista/pyvista/issues/2370
     arr3 = pv.core.utilities.arrays.convert_array(
-        pickle.loads(pickle.dumps(np.arange(4).astype('O'))), array_type=np.dtype('O')
+        pickle.loads(pickle.dumps(np.arange(4).astype('O'))),
+        array_type=np.dtype('O'),
     )
     assert arr3.GetNumberOfValues() == 4
 
@@ -693,13 +702,20 @@ def test_convert_array():
     arr4 = pv.core.utilities.arrays.convert_array(my_list)
     assert arr4.GetNumberOfValues() == len(my_list)
 
+    # test string scalar is converted to string array with length on
+    my_str = 'abc'
+    arr5 = pv.core.utilities.arrays.convert_array(my_str)
+    assert arr5.GetNumberOfValues() == 1
+    arr6 = pv.core.utilities.arrays.convert_array(np.array(my_str))
+    assert arr6.GetNumberOfValues() == 1
+
 
 def test_has_duplicates():
     assert not has_duplicates(np.arange(100))
     assert has_duplicates(np.array([0, 1, 2, 2]))
     assert has_duplicates(np.array([[0, 1, 2], [0, 1, 2]]))
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         raise_has_duplicates(np.array([0, 1, 2, 2]))
 
 
@@ -727,17 +743,17 @@ def test_copy_vtk_array():
 def test_cartesian_to_spherical():
     def polar2cart(r, phi, theta):
         return np.vstack(
-            (r * np.sin(phi) * np.cos(theta), r * np.sin(phi) * np.sin(theta), r * np.cos(phi))
+            (r * np.sin(phi) * np.cos(theta), r * np.sin(phi) * np.sin(theta), r * np.cos(phi)),
         ).T
 
-    points = np.random.random((1000, 3))
+    points = np.random.default_rng().random((1000, 3))
     x, y, z = points.T
     r, phi, theta = pv.cartesian_to_spherical(x, y, z)
     assert np.allclose(polar2cart(r, phi, theta), points)
 
 
 def test_spherical_to_cartesian():
-    points = np.random.random((1000, 3))
+    points = np.random.default_rng().random((1000, 3))
     r, phi, theta = points.T
     x, y, z = pv.spherical_to_cartesian(r, phi, theta)
     assert np.allclose(pv.cartesian_to_spherical(x, y, z), points.T)
@@ -750,7 +766,7 @@ def test_set_pickle_format():
     pv.set_pickle_format('xml')
     assert pv.PICKLE_FORMAT == 'xml'
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         pv.set_pickle_format('invalid_format')
 
 
@@ -846,7 +862,7 @@ def test_coerce_point_like_arg_copy():
 
 def test_coerce_point_like_arg_errors():
     # wrong length sequence
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         _coerce_pointslike_arg([1, 2])
 
     # wrong type
@@ -855,18 +871,18 @@ def test_coerce_point_like_arg_errors():
         _coerce_pointslike_arg({1, 2, 3})
 
     # wrong length ndarray
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         _coerce_pointslike_arg(np.empty(4))
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         _coerce_pointslike_arg(np.empty([2, 4]))
 
     # wrong ndim ndarray
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError):  # noqa: PT011
         _coerce_pointslike_arg(np.empty([1, 3, 3]))
 
 
 def test_coerce_points_like_args_does_not_copy():
-    source = np.random.rand(100, 3)
+    source = np.random.default_rng().random((100, 3))
     output, _ = _coerce_pointslike_arg(source)  # test that copy=False is default
     output /= 2
     assert np.array_equal(output, source)
@@ -921,46 +937,111 @@ def test_coerce_transformlike_arg_raises():
         _coerce_transformlike_arg("abc")
 
 
-@pytest.mark.parametrize('as_any', [True, False])
-@pytest.mark.parametrize('copy', [True, False])
-@pytest.mark.parametrize('dtype', [None, float])
-def test_cast_to_ndarray(as_any, copy, dtype):
-    array_in = pyvista_ndarray([1, 2])
-    array_out = cast_to_ndarray(array_in, copy=copy, as_any=as_any, dtype=dtype)
-    assert np.array_equal(array_out, array_in)
-    if as_any:
-        assert type(array_out) is pyvista_ndarray
-    else:
-        assert type(array_out) is np.ndarray
+@pytest.fixture()
+def no_new_attr_subclass():
+    @no_new_attr
+    class A: ...
 
-    if copy:
-        assert array_out is not array_in
+    class B(A):
+        _new_attr_exceptions = 'eggs'
 
-    if dtype is None:
-        assert array_out.dtype.type is array_in.dtype.type
-    else:
-        assert array_out.dtype.type is np.dtype(dtype).type
+        def __init__(self):
+            self.eggs = 'ham'
+
+    return B
 
 
-def test_cast_to_ndarray_raises():
-    msg = "Input cannot be cast as <class 'numpy.ndarray'>."
-    with pytest.raises(ValueError, match=msg):
-        cast_to_ndarray([[1], [2, 3]])
+def test_no_new_attr_subclass(no_new_attr_subclass):
+    obj = no_new_attr_subclass()
+    assert obj
+    msg = 'Attribute "_eggs" does not exist and cannot be added to type B'
+    with pytest.raises(AttributeError, match=msg):
+        obj._eggs = 'ham'
 
 
-def test_cast_to_tuple_array():
-    array_in = np.zeros(shape=(2, 2, 3))
-    array_tuple = cast_to_tuple_array(array_in)
-    assert array_tuple == (((0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0)))
-    array_list = array_in.tolist()
-    assert np.array_equal(array_tuple, array_list)
-    with pytest.raises(ValueError):
-        cast_to_tuple_array([[1, [2, 3]]])
+@pytest.fixture()
+def serial_dict_empty():
+    return _SerializedDictArray()
 
 
-def test_cast_to_list_array():
-    array_in = np.zeros(shape=(3, 4, 5))
-    array_list = cast_to_list_array(array_in)
-    assert np.array_equal(array_in, array_list)
-    with pytest.raises(ValueError):
-        cast_to_tuple_array([[1, [2, 3]]])
+@pytest.fixture()
+def serial_dict_with_foobar():
+    serial_dict = _SerializedDictArray()
+    serial_dict.data = dict(foo='bar')
+    return serial_dict
+
+
+def test_serial_dict_init():
+    # empty init
+    serial_dict = _SerializedDictArray()
+    assert serial_dict == {}
+    assert repr(serial_dict) == '{}'
+
+    # init from dict
+    new_dict = dict(ham='eggs')
+    serial_dict = _SerializedDictArray(new_dict)
+    assert serial_dict['ham'] == 'eggs'
+    assert repr(serial_dict) == '{"ham": "eggs"}'
+
+    # init from UserDict
+    serial_dict = _SerializedDictArray(serial_dict)
+    assert serial_dict['ham'] == 'eggs'
+    assert repr(serial_dict) == '{"ham": "eggs"}'
+
+    # init from JSON string
+    json_dict = json.dumps(new_dict)
+    serial_dict = _SerializedDictArray(json_dict)
+    assert serial_dict['ham'] == 'eggs'
+    assert repr(serial_dict) == '{"ham": "eggs"}'
+
+
+def test_serial_dict_as_dict(serial_dict_with_foobar):
+    assert not isinstance(serial_dict_with_foobar, dict)
+    actual_dict = dict(serial_dict_with_foobar)
+    assert isinstance(actual_dict, dict)
+    assert actual_dict == serial_dict_with_foobar.data
+
+
+def test_serial_dict_overrides__setitem__(serial_dict_empty):
+    serial_dict_empty['foo'] = 'bar'
+    assert repr(serial_dict_empty) == '{"foo": "bar"}'
+
+
+def test_serial_dict_overrides__delitem__(serial_dict_with_foobar):
+    del serial_dict_with_foobar['foo']
+    assert repr(serial_dict_with_foobar) == '{}'
+
+
+def test_serial_dict_overrides__setattr__(serial_dict_empty):
+    serial_dict_empty.data = dict(foo='bar')
+    assert repr(serial_dict_empty) == '{"foo": "bar"}'
+
+
+def test_serial_dict_overrides_popitem(serial_dict_with_foobar):
+    serial_dict_with_foobar['ham'] = 'eggs'
+    item = serial_dict_with_foobar.popitem()
+    assert item == ('foo', 'bar')
+    assert repr(serial_dict_with_foobar) == '{"ham": "eggs"}'
+
+
+def test_serial_dict_overrides_pop(serial_dict_with_foobar):
+    item = serial_dict_with_foobar.pop('foo')
+    assert item == 'bar'
+    assert repr(serial_dict_with_foobar) == '{}'
+
+
+def test_serial_dict_overrides_update(serial_dict_empty):
+    serial_dict_empty.update(dict(foo='bar'))
+    assert repr(serial_dict_empty) == '{"foo": "bar"}'
+
+
+def test_serial_dict_overrides_clear(serial_dict_with_foobar):
+    serial_dict_with_foobar.clear()
+    assert repr(serial_dict_with_foobar) == '{}'
+
+
+def test_serial_dict_overrides_setdefault(serial_dict_empty, serial_dict_with_foobar):
+    serial_dict_empty.setdefault('foo', 42)
+    assert repr(serial_dict_empty) == '{"foo": 42}'
+    serial_dict_with_foobar.setdefault('foo', 42)
+    assert repr(serial_dict_with_foobar) == '{"foo": "bar"}'
