@@ -1,4 +1,6 @@
-import pathlib
+from __future__ import annotations
+
+from pathlib import Path
 
 import pytest
 
@@ -7,8 +9,8 @@ import pyvista as pv
 # Use cleaned data to avoid things like `np`, `os`, etc
 # This prevents testing against things that are not intended
 # to be in the public namespace
-namespace_data = pathlib.Path(__file__).parent / 'namespace-top.txt'
-with open(namespace_data) as f:
+namespace_data = Path(__file__).parent / 'namespace-top.txt'
+with namespace_data.open() as f:
     namespace = f.read().splitlines()
     # ignore commented data
     namespace = [n.split(', ')[0] for n in namespace if not n.startswith('#')]
